# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['ActiveDirectoryJoinDomainWithAllNodesArgs', 'ActiveDirectoryJoinDomainWithAllNodes']

@pulumi.input_type
class ActiveDirectoryJoinDomainWithAllNodesArgs:
    def __init__(__self__, *,
                 additional_datas: pulumi.Input[Sequence[pulumi.Input['ActiveDirectoryJoinDomainWithAllNodesAdditionalDataArgs']]],
                 join_point_id: pulumi.Input[_builtins.str]):
        """
        The set of arguments for constructing a ActiveDirectoryJoinDomainWithAllNodes resource.
        :param pulumi.Input[_builtins.str] join_point_id: Active Directory Join Point ID
        """
        pulumi.set(__self__, "additional_datas", additional_datas)
        pulumi.set(__self__, "join_point_id", join_point_id)

    @_builtins.property
    @pulumi.getter(name="additionalDatas")
    def additional_datas(self) -> pulumi.Input[Sequence[pulumi.Input['ActiveDirectoryJoinDomainWithAllNodesAdditionalDataArgs']]]:
        return pulumi.get(self, "additional_datas")

    @additional_datas.setter
    def additional_datas(self, value: pulumi.Input[Sequence[pulumi.Input['ActiveDirectoryJoinDomainWithAllNodesAdditionalDataArgs']]]):
        pulumi.set(self, "additional_datas", value)

    @_builtins.property
    @pulumi.getter(name="joinPointId")
    def join_point_id(self) -> pulumi.Input[_builtins.str]:
        """
        Active Directory Join Point ID
        """
        return pulumi.get(self, "join_point_id")

    @join_point_id.setter
    def join_point_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "join_point_id", value)


@pulumi.input_type
class _ActiveDirectoryJoinDomainWithAllNodesState:
    def __init__(__self__, *,
                 additional_datas: Optional[pulumi.Input[Sequence[pulumi.Input['ActiveDirectoryJoinDomainWithAllNodesAdditionalDataArgs']]]] = None,
                 join_point_id: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering ActiveDirectoryJoinDomainWithAllNodes resources.
        :param pulumi.Input[_builtins.str] join_point_id: Active Directory Join Point ID
        """
        if additional_datas is not None:
            pulumi.set(__self__, "additional_datas", additional_datas)
        if join_point_id is not None:
            pulumi.set(__self__, "join_point_id", join_point_id)

    @_builtins.property
    @pulumi.getter(name="additionalDatas")
    def additional_datas(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ActiveDirectoryJoinDomainWithAllNodesAdditionalDataArgs']]]]:
        return pulumi.get(self, "additional_datas")

    @additional_datas.setter
    def additional_datas(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ActiveDirectoryJoinDomainWithAllNodesAdditionalDataArgs']]]]):
        pulumi.set(self, "additional_datas", value)

    @_builtins.property
    @pulumi.getter(name="joinPointId")
    def join_point_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Active Directory Join Point ID
        """
        return pulumi.get(self, "join_point_id")

    @join_point_id.setter
    def join_point_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "join_point_id", value)


@pulumi.type_token("ise:identitymanagement/activeDirectoryJoinDomainWithAllNodes:ActiveDirectoryJoinDomainWithAllNodes")
class ActiveDirectoryJoinDomainWithAllNodes(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 additional_datas: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ActiveDirectoryJoinDomainWithAllNodesAdditionalDataArgs', 'ActiveDirectoryJoinDomainWithAllNodesAdditionalDataArgsDict']]]]] = None,
                 join_point_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        This resource can manage an Active Directory Join Domain with All Nodes.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ise as ise

        example = ise.identitymanagement.ActiveDirectoryJoinDomainWithAllNodes("example",
            join_point_id="73808580-b6e6-11ee-8960-de6d7692bc40",
            additional_datas=[{
                "name": "username",
                "value": "administrator",
            }])
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] join_point_id: Active Directory Join Point ID
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ActiveDirectoryJoinDomainWithAllNodesArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        This resource can manage an Active Directory Join Domain with All Nodes.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ise as ise

        example = ise.identitymanagement.ActiveDirectoryJoinDomainWithAllNodes("example",
            join_point_id="73808580-b6e6-11ee-8960-de6d7692bc40",
            additional_datas=[{
                "name": "username",
                "value": "administrator",
            }])
        ```

        :param str resource_name: The name of the resource.
        :param ActiveDirectoryJoinDomainWithAllNodesArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ActiveDirectoryJoinDomainWithAllNodesArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 additional_datas: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ActiveDirectoryJoinDomainWithAllNodesAdditionalDataArgs', 'ActiveDirectoryJoinDomainWithAllNodesAdditionalDataArgsDict']]]]] = None,
                 join_point_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ActiveDirectoryJoinDomainWithAllNodesArgs.__new__(ActiveDirectoryJoinDomainWithAllNodesArgs)

            if additional_datas is None and not opts.urn:
                raise TypeError("Missing required property 'additional_datas'")
            __props__.__dict__["additional_datas"] = additional_datas
            if join_point_id is None and not opts.urn:
                raise TypeError("Missing required property 'join_point_id'")
            __props__.__dict__["join_point_id"] = join_point_id
        super(ActiveDirectoryJoinDomainWithAllNodes, __self__).__init__(
            'ise:identitymanagement/activeDirectoryJoinDomainWithAllNodes:ActiveDirectoryJoinDomainWithAllNodes',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            additional_datas: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ActiveDirectoryJoinDomainWithAllNodesAdditionalDataArgs', 'ActiveDirectoryJoinDomainWithAllNodesAdditionalDataArgsDict']]]]] = None,
            join_point_id: Optional[pulumi.Input[_builtins.str]] = None) -> 'ActiveDirectoryJoinDomainWithAllNodes':
        """
        Get an existing ActiveDirectoryJoinDomainWithAllNodes resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] join_point_id: Active Directory Join Point ID
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ActiveDirectoryJoinDomainWithAllNodesState.__new__(_ActiveDirectoryJoinDomainWithAllNodesState)

        __props__.__dict__["additional_datas"] = additional_datas
        __props__.__dict__["join_point_id"] = join_point_id
        return ActiveDirectoryJoinDomainWithAllNodes(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="additionalDatas")
    def additional_datas(self) -> pulumi.Output[Sequence['outputs.ActiveDirectoryJoinDomainWithAllNodesAdditionalData']]:
        return pulumi.get(self, "additional_datas")

    @_builtins.property
    @pulumi.getter(name="joinPointId")
    def join_point_id(self) -> pulumi.Output[_builtins.str]:
        """
        Active Directory Join Point ID
        """
        return pulumi.get(self, "join_point_id")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['CertificateAuthenticationProfileArgs', 'CertificateAuthenticationProfile']

@pulumi.input_type
class CertificateAuthenticationProfileArgs:
    def __init__(__self__, *,
                 allowed_as_user_name: Optional[pulumi.Input[_builtins.bool]] = None,
                 certificate_attribute_name: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 external_identity_store_name: Optional[pulumi.Input[_builtins.str]] = None,
                 match_mode: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 username_from: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a CertificateAuthenticationProfile resource.
        :param pulumi.Input[_builtins.bool] allowed_as_user_name: Allow as username - Default value: `false`
        :param pulumi.Input[_builtins.str] certificate_attribute_name: Attribute name of the Certificate Profile - used only when CERTIFICATE is chosen in `username_from`. - Choices:
               `SUBJECT_COMMON_NAME`, `SUBJECT_ALTERNATIVE_NAME`, `SUBJECT_SERIAL_NUMBER`, `SUBJECT`,
               `SUBJECT_ALTERNATIVE_NAME_OTHER_NAME`, `SUBJECT_ALTERNATIVE_NAME_EMAIL`, `SUBJECT_ALTERNATIVE_NAME_DNS` - Default value:
               `SUBJECT_COMMON_NAME`
        :param pulumi.Input[_builtins.str] description: Description
        :param pulumi.Input[_builtins.str] external_identity_store_name: Referred IDStore name for the Certificate Profile or `[not applicable]` in case no identity store is chosen - Default
               value: `[not applicable]`
        :param pulumi.Input[_builtins.str] match_mode: Match mode of the Certificate Profile. Allowed values: NEVER, RESOLVE_IDENTITY_AMBIGUITY, BINARY_COMPARISON - Choices:
               `NEVER`, `RESOLVE_IDENTITY_AMBIGUITY`, `BINARY_COMPARISON` - Default value: `NEVER`
        :param pulumi.Input[_builtins.str] name: The name of the certificate profile
        :param pulumi.Input[_builtins.str] username_from: The attribute in the certificate where the user name should be taken from. Allowed values: `CERTIFICATE` (for a specific
               attribute as defined in certificateAttributeName), `UPN` (for using any Subject or Alternative Name Attributes in the
               Certificate - an option only in AD) - Choices: `CERTIFICATE`, `UPN` - Default value: `CERTIFICATE`
        """
        if allowed_as_user_name is not None:
            pulumi.set(__self__, "allowed_as_user_name", allowed_as_user_name)
        if certificate_attribute_name is not None:
            pulumi.set(__self__, "certificate_attribute_name", certificate_attribute_name)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if external_identity_store_name is not None:
            pulumi.set(__self__, "external_identity_store_name", external_identity_store_name)
        if match_mode is not None:
            pulumi.set(__self__, "match_mode", match_mode)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if username_from is not None:
            pulumi.set(__self__, "username_from", username_from)

    @_builtins.property
    @pulumi.getter(name="allowedAsUserName")
    def allowed_as_user_name(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Allow as username - Default value: `false`
        """
        return pulumi.get(self, "allowed_as_user_name")

    @allowed_as_user_name.setter
    def allowed_as_user_name(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "allowed_as_user_name", value)

    @_builtins.property
    @pulumi.getter(name="certificateAttributeName")
    def certificate_attribute_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Attribute name of the Certificate Profile - used only when CERTIFICATE is chosen in `username_from`. - Choices:
        `SUBJECT_COMMON_NAME`, `SUBJECT_ALTERNATIVE_NAME`, `SUBJECT_SERIAL_NUMBER`, `SUBJECT`,
        `SUBJECT_ALTERNATIVE_NAME_OTHER_NAME`, `SUBJECT_ALTERNATIVE_NAME_EMAIL`, `SUBJECT_ALTERNATIVE_NAME_DNS` - Default value:
        `SUBJECT_COMMON_NAME`
        """
        return pulumi.get(self, "certificate_attribute_name")

    @certificate_attribute_name.setter
    def certificate_attribute_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "certificate_attribute_name", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Description
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter(name="externalIdentityStoreName")
    def external_identity_store_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Referred IDStore name for the Certificate Profile or `[not applicable]` in case no identity store is chosen - Default
        value: `[not applicable]`
        """
        return pulumi.get(self, "external_identity_store_name")

    @external_identity_store_name.setter
    def external_identity_store_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "external_identity_store_name", value)

    @_builtins.property
    @pulumi.getter(name="matchMode")
    def match_mode(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Match mode of the Certificate Profile. Allowed values: NEVER, RESOLVE_IDENTITY_AMBIGUITY, BINARY_COMPARISON - Choices:
        `NEVER`, `RESOLVE_IDENTITY_AMBIGUITY`, `BINARY_COMPARISON` - Default value: `NEVER`
        """
        return pulumi.get(self, "match_mode")

    @match_mode.setter
    def match_mode(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "match_mode", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the certificate profile
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="usernameFrom")
    def username_from(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The attribute in the certificate where the user name should be taken from. Allowed values: `CERTIFICATE` (for a specific
        attribute as defined in certificateAttributeName), `UPN` (for using any Subject or Alternative Name Attributes in the
        Certificate - an option only in AD) - Choices: `CERTIFICATE`, `UPN` - Default value: `CERTIFICATE`
        """
        return pulumi.get(self, "username_from")

    @username_from.setter
    def username_from(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "username_from", value)


@pulumi.input_type
class _CertificateAuthenticationProfileState:
    def __init__(__self__, *,
                 allowed_as_user_name: Optional[pulumi.Input[_builtins.bool]] = None,
                 certificate_attribute_name: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 external_identity_store_name: Optional[pulumi.Input[_builtins.str]] = None,
                 match_mode: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 username_from: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering CertificateAuthenticationProfile resources.
        :param pulumi.Input[_builtins.bool] allowed_as_user_name: Allow as username - Default value: `false`
        :param pulumi.Input[_builtins.str] certificate_attribute_name: Attribute name of the Certificate Profile - used only when CERTIFICATE is chosen in `username_from`. - Choices:
               `SUBJECT_COMMON_NAME`, `SUBJECT_ALTERNATIVE_NAME`, `SUBJECT_SERIAL_NUMBER`, `SUBJECT`,
               `SUBJECT_ALTERNATIVE_NAME_OTHER_NAME`, `SUBJECT_ALTERNATIVE_NAME_EMAIL`, `SUBJECT_ALTERNATIVE_NAME_DNS` - Default value:
               `SUBJECT_COMMON_NAME`
        :param pulumi.Input[_builtins.str] description: Description
        :param pulumi.Input[_builtins.str] external_identity_store_name: Referred IDStore name for the Certificate Profile or `[not applicable]` in case no identity store is chosen - Default
               value: `[not applicable]`
        :param pulumi.Input[_builtins.str] match_mode: Match mode of the Certificate Profile. Allowed values: NEVER, RESOLVE_IDENTITY_AMBIGUITY, BINARY_COMPARISON - Choices:
               `NEVER`, `RESOLVE_IDENTITY_AMBIGUITY`, `BINARY_COMPARISON` - Default value: `NEVER`
        :param pulumi.Input[_builtins.str] name: The name of the certificate profile
        :param pulumi.Input[_builtins.str] username_from: The attribute in the certificate where the user name should be taken from. Allowed values: `CERTIFICATE` (for a specific
               attribute as defined in certificateAttributeName), `UPN` (for using any Subject or Alternative Name Attributes in the
               Certificate - an option only in AD) - Choices: `CERTIFICATE`, `UPN` - Default value: `CERTIFICATE`
        """
        if allowed_as_user_name is not None:
            pulumi.set(__self__, "allowed_as_user_name", allowed_as_user_name)
        if certificate_attribute_name is not None:
            pulumi.set(__self__, "certificate_attribute_name", certificate_attribute_name)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if external_identity_store_name is not None:
            pulumi.set(__self__, "external_identity_store_name", external_identity_store_name)
        if match_mode is not None:
            pulumi.set(__self__, "match_mode", match_mode)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if username_from is not None:
            pulumi.set(__self__, "username_from", username_from)

    @_builtins.property
    @pulumi.getter(name="allowedAsUserName")
    def allowed_as_user_name(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Allow as username - Default value: `false`
        """
        return pulumi.get(self, "allowed_as_user_name")

    @allowed_as_user_name.setter
    def allowed_as_user_name(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "allowed_as_user_name", value)

    @_builtins.property
    @pulumi.getter(name="certificateAttributeName")
    def certificate_attribute_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Attribute name of the Certificate Profile - used only when CERTIFICATE is chosen in `username_from`. - Choices:
        `SUBJECT_COMMON_NAME`, `SUBJECT_ALTERNATIVE_NAME`, `SUBJECT_SERIAL_NUMBER`, `SUBJECT`,
        `SUBJECT_ALTERNATIVE_NAME_OTHER_NAME`, `SUBJECT_ALTERNATIVE_NAME_EMAIL`, `SUBJECT_ALTERNATIVE_NAME_DNS` - Default value:
        `SUBJECT_COMMON_NAME`
        """
        return pulumi.get(self, "certificate_attribute_name")

    @certificate_attribute_name.setter
    def certificate_attribute_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "certificate_attribute_name", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Description
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter(name="externalIdentityStoreName")
    def external_identity_store_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Referred IDStore name for the Certificate Profile or `[not applicable]` in case no identity store is chosen - Default
        value: `[not applicable]`
        """
        return pulumi.get(self, "external_identity_store_name")

    @external_identity_store_name.setter
    def external_identity_store_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "external_identity_store_name", value)

    @_builtins.property
    @pulumi.getter(name="matchMode")
    def match_mode(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Match mode of the Certificate Profile. Allowed values: NEVER, RESOLVE_IDENTITY_AMBIGUITY, BINARY_COMPARISON - Choices:
        `NEVER`, `RESOLVE_IDENTITY_AMBIGUITY`, `BINARY_COMPARISON` - Default value: `NEVER`
        """
        return pulumi.get(self, "match_mode")

    @match_mode.setter
    def match_mode(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "match_mode", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the certificate profile
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="usernameFrom")
    def username_from(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The attribute in the certificate where the user name should be taken from. Allowed values: `CERTIFICATE` (for a specific
        attribute as defined in certificateAttributeName), `UPN` (for using any Subject or Alternative Name Attributes in the
        Certificate - an option only in AD) - Choices: `CERTIFICATE`, `UPN` - Default value: `CERTIFICATE`
        """
        return pulumi.get(self, "username_from")

    @username_from.setter
    def username_from(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "username_from", value)


@pulumi.type_token("ise:identitymanagement/certificateAuthenticationProfile:CertificateAuthenticationProfile")
class CertificateAuthenticationProfile(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 allowed_as_user_name: Optional[pulumi.Input[_builtins.bool]] = None,
                 certificate_attribute_name: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 external_identity_store_name: Optional[pulumi.Input[_builtins.str]] = None,
                 match_mode: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 username_from: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        This resource can manage a Certificate Authentication Profile.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ise as ise

        example = ise.identitymanagement.CertificateAuthenticationProfile("example",
            name="CertProf1",
            description="My cert profile",
            allowed_as_user_name=False,
            external_identity_store_name="[not applicable]",
            certificate_attribute_name="SUBJECT_COMMON_NAME",
            match_mode="NEVER",
            username_from="CERTIFICATE")
        ```

        ## Import

        The `pulumi import` command can be used, for example:

        ```sh
        $ pulumi import ise:identitymanagement/certificateAuthenticationProfile:CertificateAuthenticationProfile example "76d24097-41c4-4558-a4d0-a8c07ac08470"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.bool] allowed_as_user_name: Allow as username - Default value: `false`
        :param pulumi.Input[_builtins.str] certificate_attribute_name: Attribute name of the Certificate Profile - used only when CERTIFICATE is chosen in `username_from`. - Choices:
               `SUBJECT_COMMON_NAME`, `SUBJECT_ALTERNATIVE_NAME`, `SUBJECT_SERIAL_NUMBER`, `SUBJECT`,
               `SUBJECT_ALTERNATIVE_NAME_OTHER_NAME`, `SUBJECT_ALTERNATIVE_NAME_EMAIL`, `SUBJECT_ALTERNATIVE_NAME_DNS` - Default value:
               `SUBJECT_COMMON_NAME`
        :param pulumi.Input[_builtins.str] description: Description
        :param pulumi.Input[_builtins.str] external_identity_store_name: Referred IDStore name for the Certificate Profile or `[not applicable]` in case no identity store is chosen - Default
               value: `[not applicable]`
        :param pulumi.Input[_builtins.str] match_mode: Match mode of the Certificate Profile. Allowed values: NEVER, RESOLVE_IDENTITY_AMBIGUITY, BINARY_COMPARISON - Choices:
               `NEVER`, `RESOLVE_IDENTITY_AMBIGUITY`, `BINARY_COMPARISON` - Default value: `NEVER`
        :param pulumi.Input[_builtins.str] name: The name of the certificate profile
        :param pulumi.Input[_builtins.str] username_from: The attribute in the certificate where the user name should be taken from. Allowed values: `CERTIFICATE` (for a specific
               attribute as defined in certificateAttributeName), `UPN` (for using any Subject or Alternative Name Attributes in the
               Certificate - an option only in AD) - Choices: `CERTIFICATE`, `UPN` - Default value: `CERTIFICATE`
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[CertificateAuthenticationProfileArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        This resource can manage a Certificate Authentication Profile.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ise as ise

        example = ise.identitymanagement.CertificateAuthenticationProfile("example",
            name="CertProf1",
            description="My cert profile",
            allowed_as_user_name=False,
            external_identity_store_name="[not applicable]",
            certificate_attribute_name="SUBJECT_COMMON_NAME",
            match_mode="NEVER",
            username_from="CERTIFICATE")
        ```

        ## Import

        The `pulumi import` command can be used, for example:

        ```sh
        $ pulumi import ise:identitymanagement/certificateAuthenticationProfile:CertificateAuthenticationProfile example "76d24097-41c4-4558-a4d0-a8c07ac08470"
        ```

        :param str resource_name: The name of the resource.
        :param CertificateAuthenticationProfileArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(CertificateAuthenticationProfileArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 allowed_as_user_name: Optional[pulumi.Input[_builtins.bool]] = None,
                 certificate_attribute_name: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 external_identity_store_name: Optional[pulumi.Input[_builtins.str]] = None,
                 match_mode: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 username_from: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = CertificateAuthenticationProfileArgs.__new__(CertificateAuthenticationProfileArgs)

            __props__.__dict__["allowed_as_user_name"] = allowed_as_user_name
            __props__.__dict__["certificate_attribute_name"] = certificate_attribute_name
            __props__.__dict__["description"] = description
            __props__.__dict__["external_identity_store_name"] = external_identity_store_name
            __props__.__dict__["match_mode"] = match_mode
            __props__.__dict__["name"] = name
            __props__.__dict__["username_from"] = username_from
        super(CertificateAuthenticationProfile, __self__).__init__(
            'ise:identitymanagement/certificateAuthenticationProfile:CertificateAuthenticationProfile',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            allowed_as_user_name: Optional[pulumi.Input[_builtins.bool]] = None,
            certificate_attribute_name: Optional[pulumi.Input[_builtins.str]] = None,
            description: Optional[pulumi.Input[_builtins.str]] = None,
            external_identity_store_name: Optional[pulumi.Input[_builtins.str]] = None,
            match_mode: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            username_from: Optional[pulumi.Input[_builtins.str]] = None) -> 'CertificateAuthenticationProfile':
        """
        Get an existing CertificateAuthenticationProfile resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.bool] allowed_as_user_name: Allow as username - Default value: `false`
        :param pulumi.Input[_builtins.str] certificate_attribute_name: Attribute name of the Certificate Profile - used only when CERTIFICATE is chosen in `username_from`. - Choices:
               `SUBJECT_COMMON_NAME`, `SUBJECT_ALTERNATIVE_NAME`, `SUBJECT_SERIAL_NUMBER`, `SUBJECT`,
               `SUBJECT_ALTERNATIVE_NAME_OTHER_NAME`, `SUBJECT_ALTERNATIVE_NAME_EMAIL`, `SUBJECT_ALTERNATIVE_NAME_DNS` - Default value:
               `SUBJECT_COMMON_NAME`
        :param pulumi.Input[_builtins.str] description: Description
        :param pulumi.Input[_builtins.str] external_identity_store_name: Referred IDStore name for the Certificate Profile or `[not applicable]` in case no identity store is chosen - Default
               value: `[not applicable]`
        :param pulumi.Input[_builtins.str] match_mode: Match mode of the Certificate Profile. Allowed values: NEVER, RESOLVE_IDENTITY_AMBIGUITY, BINARY_COMPARISON - Choices:
               `NEVER`, `RESOLVE_IDENTITY_AMBIGUITY`, `BINARY_COMPARISON` - Default value: `NEVER`
        :param pulumi.Input[_builtins.str] name: The name of the certificate profile
        :param pulumi.Input[_builtins.str] username_from: The attribute in the certificate where the user name should be taken from. Allowed values: `CERTIFICATE` (for a specific
               attribute as defined in certificateAttributeName), `UPN` (for using any Subject or Alternative Name Attributes in the
               Certificate - an option only in AD) - Choices: `CERTIFICATE`, `UPN` - Default value: `CERTIFICATE`
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _CertificateAuthenticationProfileState.__new__(_CertificateAuthenticationProfileState)

        __props__.__dict__["allowed_as_user_name"] = allowed_as_user_name
        __props__.__dict__["certificate_attribute_name"] = certificate_attribute_name
        __props__.__dict__["description"] = description
        __props__.__dict__["external_identity_store_name"] = external_identity_store_name
        __props__.__dict__["match_mode"] = match_mode
        __props__.__dict__["name"] = name
        __props__.__dict__["username_from"] = username_from
        return CertificateAuthenticationProfile(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="allowedAsUserName")
    def allowed_as_user_name(self) -> pulumi.Output[_builtins.bool]:
        """
        Allow as username - Default value: `false`
        """
        return pulumi.get(self, "allowed_as_user_name")

    @_builtins.property
    @pulumi.getter(name="certificateAttributeName")
    def certificate_attribute_name(self) -> pulumi.Output[_builtins.str]:
        """
        Attribute name of the Certificate Profile - used only when CERTIFICATE is chosen in `username_from`. - Choices:
        `SUBJECT_COMMON_NAME`, `SUBJECT_ALTERNATIVE_NAME`, `SUBJECT_SERIAL_NUMBER`, `SUBJECT`,
        `SUBJECT_ALTERNATIVE_NAME_OTHER_NAME`, `SUBJECT_ALTERNATIVE_NAME_EMAIL`, `SUBJECT_ALTERNATIVE_NAME_DNS` - Default value:
        `SUBJECT_COMMON_NAME`
        """
        return pulumi.get(self, "certificate_attribute_name")

    @_builtins.property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Description
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter(name="externalIdentityStoreName")
    def external_identity_store_name(self) -> pulumi.Output[_builtins.str]:
        """
        Referred IDStore name for the Certificate Profile or `[not applicable]` in case no identity store is chosen - Default
        value: `[not applicable]`
        """
        return pulumi.get(self, "external_identity_store_name")

    @_builtins.property
    @pulumi.getter(name="matchMode")
    def match_mode(self) -> pulumi.Output[_builtins.str]:
        """
        Match mode of the Certificate Profile. Allowed values: NEVER, RESOLVE_IDENTITY_AMBIGUITY, BINARY_COMPARISON - Choices:
        `NEVER`, `RESOLVE_IDENTITY_AMBIGUITY`, `BINARY_COMPARISON` - Default value: `NEVER`
        """
        return pulumi.get(self, "match_mode")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        The name of the certificate profile
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="usernameFrom")
    def username_from(self) -> pulumi.Output[_builtins.str]:
        """
        The attribute in the certificate where the user name should be taken from. Allowed values: `CERTIFICATE` (for a specific
        attribute as defined in certificateAttributeName), `UPN` (for using any Subject or Alternative Name Attributes in the
        Certificate - an option only in AD) - Choices: `CERTIFICATE`, `UPN` - Default value: `CERTIFICATE`
        """
        return pulumi.get(self, "username_from")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['AuthorizationRuleUpdateRankArgs', 'AuthorizationRuleUpdateRank']

@pulumi.input_type
class AuthorizationRuleUpdateRankArgs:
    def __init__(__self__, *,
                 policy_set_id: pulumi.Input[_builtins.str],
                 rank: pulumi.Input[_builtins.int],
                 rule_id: pulumi.Input[_builtins.str]):
        """
        The set of arguments for constructing a AuthorizationRuleUpdateRank resource.
        :param pulumi.Input[_builtins.str] policy_set_id: Policy set ID
        :param pulumi.Input[_builtins.int] rank: The rank (priority) in relation to other rules. Lower rank is higher priority.
        :param pulumi.Input[_builtins.str] rule_id: Authorization rule ID
        """
        pulumi.set(__self__, "policy_set_id", policy_set_id)
        pulumi.set(__self__, "rank", rank)
        pulumi.set(__self__, "rule_id", rule_id)

    @_builtins.property
    @pulumi.getter(name="policySetId")
    def policy_set_id(self) -> pulumi.Input[_builtins.str]:
        """
        Policy set ID
        """
        return pulumi.get(self, "policy_set_id")

    @policy_set_id.setter
    def policy_set_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "policy_set_id", value)

    @_builtins.property
    @pulumi.getter
    def rank(self) -> pulumi.Input[_builtins.int]:
        """
        The rank (priority) in relation to other rules. Lower rank is higher priority.
        """
        return pulumi.get(self, "rank")

    @rank.setter
    def rank(self, value: pulumi.Input[_builtins.int]):
        pulumi.set(self, "rank", value)

    @_builtins.property
    @pulumi.getter(name="ruleId")
    def rule_id(self) -> pulumi.Input[_builtins.str]:
        """
        Authorization rule ID
        """
        return pulumi.get(self, "rule_id")

    @rule_id.setter
    def rule_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "rule_id", value)


@pulumi.input_type
class _AuthorizationRuleUpdateRankState:
    def __init__(__self__, *,
                 policy_set_id: Optional[pulumi.Input[_builtins.str]] = None,
                 rank: Optional[pulumi.Input[_builtins.int]] = None,
                 rule_id: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering AuthorizationRuleUpdateRank resources.
        :param pulumi.Input[_builtins.str] policy_set_id: Policy set ID
        :param pulumi.Input[_builtins.int] rank: The rank (priority) in relation to other rules. Lower rank is higher priority.
        :param pulumi.Input[_builtins.str] rule_id: Authorization rule ID
        """
        if policy_set_id is not None:
            pulumi.set(__self__, "policy_set_id", policy_set_id)
        if rank is not None:
            pulumi.set(__self__, "rank", rank)
        if rule_id is not None:
            pulumi.set(__self__, "rule_id", rule_id)

    @_builtins.property
    @pulumi.getter(name="policySetId")
    def policy_set_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Policy set ID
        """
        return pulumi.get(self, "policy_set_id")

    @policy_set_id.setter
    def policy_set_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "policy_set_id", value)

    @_builtins.property
    @pulumi.getter
    def rank(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The rank (priority) in relation to other rules. Lower rank is higher priority.
        """
        return pulumi.get(self, "rank")

    @rank.setter
    def rank(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "rank", value)

    @_builtins.property
    @pulumi.getter(name="ruleId")
    def rule_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Authorization rule ID
        """
        return pulumi.get(self, "rule_id")

    @rule_id.setter
    def rule_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "rule_id", value)


@pulumi.type_token("ise:deviceadmin/authorizationRuleUpdateRank:AuthorizationRuleUpdateRank")
class AuthorizationRuleUpdateRank(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 policy_set_id: Optional[pulumi.Input[_builtins.str]] = None,
                 rank: Optional[pulumi.Input[_builtins.int]] = None,
                 rule_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        This resource is used to update rank field in device admin authorization rule. It serves as a workaround for the ISE API/Backend limitation which restricts rank assignments to a strictly incremental sequence. By utilizing this resource and device_admin_authorization_rule resource, you can bypass the APIs limitation. Creation of this resource is performing PUT operation (Update) and it only tracks rank field. When this resource is destroyed, no action is performed on ISE and resource is just removed from state.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ise as ise

        example = ise.deviceadmin.AuthorizationRuleUpdateRank("example",
            rule_id="9b3680da-0165-44f6-9cff-88e778d98020",
            policy_set_id="d82952cb-b901-4b09-b363-5ebf39bdbaf9",
            rank=0)
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] policy_set_id: Policy set ID
        :param pulumi.Input[_builtins.int] rank: The rank (priority) in relation to other rules. Lower rank is higher priority.
        :param pulumi.Input[_builtins.str] rule_id: Authorization rule ID
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: AuthorizationRuleUpdateRankArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        This resource is used to update rank field in device admin authorization rule. It serves as a workaround for the ISE API/Backend limitation which restricts rank assignments to a strictly incremental sequence. By utilizing this resource and device_admin_authorization_rule resource, you can bypass the APIs limitation. Creation of this resource is performing PUT operation (Update) and it only tracks rank field. When this resource is destroyed, no action is performed on ISE and resource is just removed from state.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ise as ise

        example = ise.deviceadmin.AuthorizationRuleUpdateRank("example",
            rule_id="9b3680da-0165-44f6-9cff-88e778d98020",
            policy_set_id="d82952cb-b901-4b09-b363-5ebf39bdbaf9",
            rank=0)
        ```

        :param str resource_name: The name of the resource.
        :param AuthorizationRuleUpdateRankArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(AuthorizationRuleUpdateRankArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 policy_set_id: Optional[pulumi.Input[_builtins.str]] = None,
                 rank: Optional[pulumi.Input[_builtins.int]] = None,
                 rule_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = AuthorizationRuleUpdateRankArgs.__new__(AuthorizationRuleUpdateRankArgs)

            if policy_set_id is None and not opts.urn:
                raise TypeError("Missing required property 'policy_set_id'")
            __props__.__dict__["policy_set_id"] = policy_set_id
            if rank is None and not opts.urn:
                raise TypeError("Missing required property 'rank'")
            __props__.__dict__["rank"] = rank
            if rule_id is None and not opts.urn:
                raise TypeError("Missing required property 'rule_id'")
            __props__.__dict__["rule_id"] = rule_id
        super(AuthorizationRuleUpdateRank, __self__).__init__(
            'ise:deviceadmin/authorizationRuleUpdateRank:AuthorizationRuleUpdateRank',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            policy_set_id: Optional[pulumi.Input[_builtins.str]] = None,
            rank: Optional[pulumi.Input[_builtins.int]] = None,
            rule_id: Optional[pulumi.Input[_builtins.str]] = None) -> 'AuthorizationRuleUpdateRank':
        """
        Get an existing AuthorizationRuleUpdateRank resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] policy_set_id: Policy set ID
        :param pulumi.Input[_builtins.int] rank: The rank (priority) in relation to other rules. Lower rank is higher priority.
        :param pulumi.Input[_builtins.str] rule_id: Authorization rule ID
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _AuthorizationRuleUpdateRankState.__new__(_AuthorizationRuleUpdateRankState)

        __props__.__dict__["policy_set_id"] = policy_set_id
        __props__.__dict__["rank"] = rank
        __props__.__dict__["rule_id"] = rule_id
        return AuthorizationRuleUpdateRank(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="policySetId")
    def policy_set_id(self) -> pulumi.Output[_builtins.str]:
        """
        Policy set ID
        """
        return pulumi.get(self, "policy_set_id")

    @_builtins.property
    @pulumi.getter
    def rank(self) -> pulumi.Output[_builtins.int]:
        """
        The rank (priority) in relation to other rules. Lower rank is higher priority.
        """
        return pulumi.get(self, "rank")

    @_builtins.property
    @pulumi.getter(name="ruleId")
    def rule_id(self) -> pulumi.Output[_builtins.str]:
        """
        Authorization rule ID
        """
        return pulumi.get(self, "rule_id")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['AuthorizationProfileArgs', 'AuthorizationProfile']

@pulumi.input_type
class AuthorizationProfileArgs:
    def __init__(__self__, *,
                 access_type: Optional[pulumi.Input[_builtins.str]] = None,
                 acl: Optional[pulumi.Input[_builtins.str]] = None,
                 advanced_attributes: Optional[pulumi.Input[Sequence[pulumi.Input['AuthorizationProfileAdvancedAttributeArgs']]]] = None,
                 agentless_posture: Optional[pulumi.Input[_builtins.bool]] = None,
                 airespace_acl: Optional[pulumi.Input[_builtins.str]] = None,
                 airespace_ipv6_acl: Optional[pulumi.Input[_builtins.str]] = None,
                 asa_vpn: Optional[pulumi.Input[_builtins.str]] = None,
                 auto_smart_port: Optional[pulumi.Input[_builtins.str]] = None,
                 avc_profile: Optional[pulumi.Input[_builtins.str]] = None,
                 dacl_name: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 easywired_session_candidate: Optional[pulumi.Input[_builtins.bool]] = None,
                 interface_template: Optional[pulumi.Input[_builtins.str]] = None,
                 ipv6_acl_filter: Optional[pulumi.Input[_builtins.str]] = None,
                 ipv6_dacl_name: Optional[pulumi.Input[_builtins.str]] = None,
                 mac_sec_policy: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 neat: Optional[pulumi.Input[_builtins.bool]] = None,
                 profile_name: Optional[pulumi.Input[_builtins.str]] = None,
                 reauthentication_connectivity: Optional[pulumi.Input[_builtins.str]] = None,
                 reauthentication_timer: Optional[pulumi.Input[_builtins.int]] = None,
                 service_template: Optional[pulumi.Input[_builtins.bool]] = None,
                 track_movement: Optional[pulumi.Input[_builtins.bool]] = None,
                 unique_identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 vlan_name_id: Optional[pulumi.Input[_builtins.str]] = None,
                 vlan_tag_id: Optional[pulumi.Input[_builtins.int]] = None,
                 voice_domain_permission: Optional[pulumi.Input[_builtins.bool]] = None,
                 web_auth: Optional[pulumi.Input[_builtins.bool]] = None,
                 web_redirection_acl: Optional[pulumi.Input[_builtins.str]] = None,
                 web_redirection_display_certificates_renewal_messages: Optional[pulumi.Input[_builtins.bool]] = None,
                 web_redirection_portal_name: Optional[pulumi.Input[_builtins.str]] = None,
                 web_redirection_static_ip_host_name_fqdn: Optional[pulumi.Input[_builtins.str]] = None,
                 web_redirection_type: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a AuthorizationProfile resource.
        :param pulumi.Input[_builtins.str] access_type: Access type - Choices: `ACCESS_ACCEPT`, `ACCESS_REJECT` - Default value: `ACCESS_ACCEPT`
        :param pulumi.Input[_builtins.str] acl: ACL
        :param pulumi.Input[Sequence[pulumi.Input['AuthorizationProfileAdvancedAttributeArgs']]] advanced_attributes: List of advanced attributes
        :param pulumi.Input[_builtins.bool] agentless_posture: Agentless Posture.
        :param pulumi.Input[_builtins.str] airespace_acl: Airespace ACL
        :param pulumi.Input[_builtins.str] airespace_ipv6_acl: Airespace IPv6 ACL
        :param pulumi.Input[_builtins.str] asa_vpn: ASA VPN
        :param pulumi.Input[_builtins.str] auto_smart_port: Auto smart port
        :param pulumi.Input[_builtins.str] avc_profile: AVC profile
        :param pulumi.Input[_builtins.str] dacl_name: DACL name
        :param pulumi.Input[_builtins.str] description: Description
        :param pulumi.Input[_builtins.bool] easywired_session_candidate: Easy wired session candidate - Default value: `false`
        :param pulumi.Input[_builtins.str] interface_template: Interface template
        :param pulumi.Input[_builtins.str] ipv6_acl_filter: IPv6 ACL
        :param pulumi.Input[_builtins.str] ipv6_dacl_name: IPv6 DACL name
        :param pulumi.Input[_builtins.str] mac_sec_policy: MacSec policy - Choices: `MUST_SECURE`, `MUST_NOT_SECURE`, `SHOULD_SECURE`
        :param pulumi.Input[_builtins.str] name: The name of the authorization profile
        :param pulumi.Input[_builtins.bool] neat: NEAT - Default value: `false`
        :param pulumi.Input[_builtins.str] profile_name: Value needs to be an existing Network Device Profile - Default value: `Cisco`
        :param pulumi.Input[_builtins.str] reauthentication_connectivity: Maintain Connectivity During Reauthentication - Choices: `DEFAULT`, `RADIUS_REQUEST`
        :param pulumi.Input[_builtins.int] reauthentication_timer: Reauthentication timer - Range: `1`-`65535`
        :param pulumi.Input[_builtins.bool] service_template: Service template - Default value: `false`
        :param pulumi.Input[_builtins.bool] track_movement: Track movement - Default value: `false`
        :param pulumi.Input[_builtins.str] unique_identifier: Unique identifier
        :param pulumi.Input[_builtins.str] vlan_name_id: Vlan name or ID
        :param pulumi.Input[_builtins.int] vlan_tag_id: Vlan tag ID - Range: `0`-`31`
        :param pulumi.Input[_builtins.bool] voice_domain_permission: Voice domain permission - Default value: `false`
        :param pulumi.Input[_builtins.bool] web_auth: Web authentication (local) - Default value: `false`
        :param pulumi.Input[_builtins.str] web_redirection_acl: Web redirection ACL
        :param pulumi.Input[_builtins.bool] web_redirection_display_certificates_renewal_messages: This attribute is mandatory when `web_redirection_type` value is `CentralizedWebAuth`. For all other
               `web_redirection_type` values the field must be ignored.
        :param pulumi.Input[_builtins.str] web_redirection_portal_name: A portal that exist in the DB and fits the `web_redirection_type`
        :param pulumi.Input[_builtins.str] web_redirection_static_ip_host_name_fqdn: IP, hostname or FQDN
        :param pulumi.Input[_builtins.str] web_redirection_type: This type must fit the `web_redirection_portal_name` - Choices: `CentralizedWebAuth`, `HotSpot`,
               `NativeSupplicanProvisioning`, `ClientProvisioning`
        """
        if access_type is not None:
            pulumi.set(__self__, "access_type", access_type)
        if acl is not None:
            pulumi.set(__self__, "acl", acl)
        if advanced_attributes is not None:
            pulumi.set(__self__, "advanced_attributes", advanced_attributes)
        if agentless_posture is not None:
            pulumi.set(__self__, "agentless_posture", agentless_posture)
        if airespace_acl is not None:
            pulumi.set(__self__, "airespace_acl", airespace_acl)
        if airespace_ipv6_acl is not None:
            pulumi.set(__self__, "airespace_ipv6_acl", airespace_ipv6_acl)
        if asa_vpn is not None:
            pulumi.set(__self__, "asa_vpn", asa_vpn)
        if auto_smart_port is not None:
            pulumi.set(__self__, "auto_smart_port", auto_smart_port)
        if avc_profile is not None:
            pulumi.set(__self__, "avc_profile", avc_profile)
        if dacl_name is not None:
            pulumi.set(__self__, "dacl_name", dacl_name)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if easywired_session_candidate is not None:
            pulumi.set(__self__, "easywired_session_candidate", easywired_session_candidate)
        if interface_template is not None:
            pulumi.set(__self__, "interface_template", interface_template)
        if ipv6_acl_filter is not None:
            pulumi.set(__self__, "ipv6_acl_filter", ipv6_acl_filter)
        if ipv6_dacl_name is not None:
            pulumi.set(__self__, "ipv6_dacl_name", ipv6_dacl_name)
        if mac_sec_policy is not None:
            pulumi.set(__self__, "mac_sec_policy", mac_sec_policy)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if neat is not None:
            pulumi.set(__self__, "neat", neat)
        if profile_name is not None:
            pulumi.set(__self__, "profile_name", profile_name)
        if reauthentication_connectivity is not None:
            pulumi.set(__self__, "reauthentication_connectivity", reauthentication_connectivity)
        if reauthentication_timer is not None:
            pulumi.set(__self__, "reauthentication_timer", reauthentication_timer)
        if service_template is not None:
            pulumi.set(__self__, "service_template", service_template)
        if track_movement is not None:
            pulumi.set(__self__, "track_movement", track_movement)
        if unique_identifier is not None:
            pulumi.set(__self__, "unique_identifier", unique_identifier)
        if vlan_name_id is not None:
            pulumi.set(__self__, "vlan_name_id", vlan_name_id)
        if vlan_tag_id is not None:
            pulumi.set(__self__, "vlan_tag_id", vlan_tag_id)
        if voice_domain_permission is not None:
            pulumi.set(__self__, "voice_domain_permission", voice_domain_permission)
        if web_auth is not None:
            pulumi.set(__self__, "web_auth", web_auth)
        if web_redirection_acl is not None:
            pulumi.set(__self__, "web_redirection_acl", web_redirection_acl)
        if web_redirection_display_certificates_renewal_messages is not None:
            pulumi.set(__self__, "web_redirection_display_certificates_renewal_messages", web_redirection_display_certificates_renewal_messages)
        if web_redirection_portal_name is not None:
            pulumi.set(__self__, "web_redirection_portal_name", web_redirection_portal_name)
        if web_redirection_static_ip_host_name_fqdn is not None:
            pulumi.set(__self__, "web_redirection_static_ip_host_name_fqdn", web_redirection_static_ip_host_name_fqdn)
        if web_redirection_type is not None:
            pulumi.set(__self__, "web_redirection_type", web_redirection_type)

    @_builtins.property
    @pulumi.getter(name="accessType")
    def access_type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Access type - Choices: `ACCESS_ACCEPT`, `ACCESS_REJECT` - Default value: `ACCESS_ACCEPT`
        """
        return pulumi.get(self, "access_type")

    @access_type.setter
    def access_type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "access_type", value)

    @_builtins.property
    @pulumi.getter
    def acl(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        ACL
        """
        return pulumi.get(self, "acl")

    @acl.setter
    def acl(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "acl", value)

    @_builtins.property
    @pulumi.getter(name="advancedAttributes")
    def advanced_attributes(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['AuthorizationProfileAdvancedAttributeArgs']]]]:
        """
        List of advanced attributes
        """
        return pulumi.get(self, "advanced_attributes")

    @advanced_attributes.setter
    def advanced_attributes(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['AuthorizationProfileAdvancedAttributeArgs']]]]):
        pulumi.set(self, "advanced_attributes", value)

    @_builtins.property
    @pulumi.getter(name="agentlessPosture")
    def agentless_posture(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Agentless Posture.
        """
        return pulumi.get(self, "agentless_posture")

    @agentless_posture.setter
    def agentless_posture(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "agentless_posture", value)

    @_builtins.property
    @pulumi.getter(name="airespaceAcl")
    def airespace_acl(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Airespace ACL
        """
        return pulumi.get(self, "airespace_acl")

    @airespace_acl.setter
    def airespace_acl(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "airespace_acl", value)

    @_builtins.property
    @pulumi.getter(name="airespaceIpv6Acl")
    def airespace_ipv6_acl(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Airespace IPv6 ACL
        """
        return pulumi.get(self, "airespace_ipv6_acl")

    @airespace_ipv6_acl.setter
    def airespace_ipv6_acl(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "airespace_ipv6_acl", value)

    @_builtins.property
    @pulumi.getter(name="asaVpn")
    def asa_vpn(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        ASA VPN
        """
        return pulumi.get(self, "asa_vpn")

    @asa_vpn.setter
    def asa_vpn(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "asa_vpn", value)

    @_builtins.property
    @pulumi.getter(name="autoSmartPort")
    def auto_smart_port(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Auto smart port
        """
        return pulumi.get(self, "auto_smart_port")

    @auto_smart_port.setter
    def auto_smart_port(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "auto_smart_port", value)

    @_builtins.property
    @pulumi.getter(name="avcProfile")
    def avc_profile(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        AVC profile
        """
        return pulumi.get(self, "avc_profile")

    @avc_profile.setter
    def avc_profile(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "avc_profile", value)

    @_builtins.property
    @pulumi.getter(name="daclName")
    def dacl_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        DACL name
        """
        return pulumi.get(self, "dacl_name")

    @dacl_name.setter
    def dacl_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "dacl_name", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Description
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter(name="easywiredSessionCandidate")
    def easywired_session_candidate(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Easy wired session candidate - Default value: `false`
        """
        return pulumi.get(self, "easywired_session_candidate")

    @easywired_session_candidate.setter
    def easywired_session_candidate(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "easywired_session_candidate", value)

    @_builtins.property
    @pulumi.getter(name="interfaceTemplate")
    def interface_template(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Interface template
        """
        return pulumi.get(self, "interface_template")

    @interface_template.setter
    def interface_template(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "interface_template", value)

    @_builtins.property
    @pulumi.getter(name="ipv6AclFilter")
    def ipv6_acl_filter(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        IPv6 ACL
        """
        return pulumi.get(self, "ipv6_acl_filter")

    @ipv6_acl_filter.setter
    def ipv6_acl_filter(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "ipv6_acl_filter", value)

    @_builtins.property
    @pulumi.getter(name="ipv6DaclName")
    def ipv6_dacl_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        IPv6 DACL name
        """
        return pulumi.get(self, "ipv6_dacl_name")

    @ipv6_dacl_name.setter
    def ipv6_dacl_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "ipv6_dacl_name", value)

    @_builtins.property
    @pulumi.getter(name="macSecPolicy")
    def mac_sec_policy(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        MacSec policy - Choices: `MUST_SECURE`, `MUST_NOT_SECURE`, `SHOULD_SECURE`
        """
        return pulumi.get(self, "mac_sec_policy")

    @mac_sec_policy.setter
    def mac_sec_policy(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "mac_sec_policy", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the authorization profile
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def neat(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        NEAT - Default value: `false`
        """
        return pulumi.get(self, "neat")

    @neat.setter
    def neat(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "neat", value)

    @_builtins.property
    @pulumi.getter(name="profileName")
    def profile_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Value needs to be an existing Network Device Profile - Default value: `Cisco`
        """
        return pulumi.get(self, "profile_name")

    @profile_name.setter
    def profile_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "profile_name", value)

    @_builtins.property
    @pulumi.getter(name="reauthenticationConnectivity")
    def reauthentication_connectivity(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Maintain Connectivity During Reauthentication - Choices: `DEFAULT`, `RADIUS_REQUEST`
        """
        return pulumi.get(self, "reauthentication_connectivity")

    @reauthentication_connectivity.setter
    def reauthentication_connectivity(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "reauthentication_connectivity", value)

    @_builtins.property
    @pulumi.getter(name="reauthenticationTimer")
    def reauthentication_timer(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Reauthentication timer - Range: `1`-`65535`
        """
        return pulumi.get(self, "reauthentication_timer")

    @reauthentication_timer.setter
    def reauthentication_timer(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "reauthentication_timer", value)

    @_builtins.property
    @pulumi.getter(name="serviceTemplate")
    def service_template(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Service template - Default value: `false`
        """
        return pulumi.get(self, "service_template")

    @service_template.setter
    def service_template(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "service_template", value)

    @_builtins.property
    @pulumi.getter(name="trackMovement")
    def track_movement(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Track movement - Default value: `false`
        """
        return pulumi.get(self, "track_movement")

    @track_movement.setter
    def track_movement(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "track_movement", value)

    @_builtins.property
    @pulumi.getter(name="uniqueIdentifier")
    def unique_identifier(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique identifier
        """
        return pulumi.get(self, "unique_identifier")

    @unique_identifier.setter
    def unique_identifier(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "unique_identifier", value)

    @_builtins.property
    @pulumi.getter(name="vlanNameId")
    def vlan_name_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Vlan name or ID
        """
        return pulumi.get(self, "vlan_name_id")

    @vlan_name_id.setter
    def vlan_name_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "vlan_name_id", value)

    @_builtins.property
    @pulumi.getter(name="vlanTagId")
    def vlan_tag_id(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Vlan tag ID - Range: `0`-`31`
        """
        return pulumi.get(self, "vlan_tag_id")

    @vlan_tag_id.setter
    def vlan_tag_id(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "vlan_tag_id", value)

    @_builtins.property
    @pulumi.getter(name="voiceDomainPermission")
    def voice_domain_permission(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Voice domain permission - Default value: `false`
        """
        return pulumi.get(self, "voice_domain_permission")

    @voice_domain_permission.setter
    def voice_domain_permission(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "voice_domain_permission", value)

    @_builtins.property
    @pulumi.getter(name="webAuth")
    def web_auth(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Web authentication (local) - Default value: `false`
        """
        return pulumi.get(self, "web_auth")

    @web_auth.setter
    def web_auth(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "web_auth", value)

    @_builtins.property
    @pulumi.getter(name="webRedirectionAcl")
    def web_redirection_acl(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Web redirection ACL
        """
        return pulumi.get(self, "web_redirection_acl")

    @web_redirection_acl.setter
    def web_redirection_acl(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "web_redirection_acl", value)

    @_builtins.property
    @pulumi.getter(name="webRedirectionDisplayCertificatesRenewalMessages")
    def web_redirection_display_certificates_renewal_messages(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        This attribute is mandatory when `web_redirection_type` value is `CentralizedWebAuth`. For all other
        `web_redirection_type` values the field must be ignored.
        """
        return pulumi.get(self, "web_redirection_display_certificates_renewal_messages")

    @web_redirection_display_certificates_renewal_messages.setter
    def web_redirection_display_certificates_renewal_messages(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "web_redirection_display_certificates_renewal_messages", value)

    @_builtins.property
    @pulumi.getter(name="webRedirectionPortalName")
    def web_redirection_portal_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        A portal that exist in the DB and fits the `web_redirection_type`
        """
        return pulumi.get(self, "web_redirection_portal_name")

    @web_redirection_portal_name.setter
    def web_redirection_portal_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "web_redirection_portal_name", value)

    @_builtins.property
    @pulumi.getter(name="webRedirectionStaticIpHostNameFqdn")
    def web_redirection_static_ip_host_name_fqdn(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        IP, hostname or FQDN
        """
        return pulumi.get(self, "web_redirection_static_ip_host_name_fqdn")

    @web_redirection_static_ip_host_name_fqdn.setter
    def web_redirection_static_ip_host_name_fqdn(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "web_redirection_static_ip_host_name_fqdn", value)

    @_builtins.property
    @pulumi.getter(name="webRedirectionType")
    def web_redirection_type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        This type must fit the `web_redirection_portal_name` - Choices: `CentralizedWebAuth`, `HotSpot`,
        `NativeSupplicanProvisioning`, `ClientProvisioning`
        """
        return pulumi.get(self, "web_redirection_type")

    @web_redirection_type.setter
    def web_redirection_type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "web_redirection_type", value)


@pulumi.input_type
class _AuthorizationProfileState:
    def __init__(__self__, *,
                 access_type: Optional[pulumi.Input[_builtins.str]] = None,
                 acl: Optional[pulumi.Input[_builtins.str]] = None,
                 advanced_attributes: Optional[pulumi.Input[Sequence[pulumi.Input['AuthorizationProfileAdvancedAttributeArgs']]]] = None,
                 agentless_posture: Optional[pulumi.Input[_builtins.bool]] = None,
                 airespace_acl: Optional[pulumi.Input[_builtins.str]] = None,
                 airespace_ipv6_acl: Optional[pulumi.Input[_builtins.str]] = None,
                 asa_vpn: Optional[pulumi.Input[_builtins.str]] = None,
                 auto_smart_port: Optional[pulumi.Input[_builtins.str]] = None,
                 avc_profile: Optional[pulumi.Input[_builtins.str]] = None,
                 dacl_name: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 easywired_session_candidate: Optional[pulumi.Input[_builtins.bool]] = None,
                 interface_template: Optional[pulumi.Input[_builtins.str]] = None,
                 ipv6_acl_filter: Optional[pulumi.Input[_builtins.str]] = None,
                 ipv6_dacl_name: Optional[pulumi.Input[_builtins.str]] = None,
                 mac_sec_policy: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 neat: Optional[pulumi.Input[_builtins.bool]] = None,
                 profile_name: Optional[pulumi.Input[_builtins.str]] = None,
                 reauthentication_connectivity: Optional[pulumi.Input[_builtins.str]] = None,
                 reauthentication_timer: Optional[pulumi.Input[_builtins.int]] = None,
                 service_template: Optional[pulumi.Input[_builtins.bool]] = None,
                 track_movement: Optional[pulumi.Input[_builtins.bool]] = None,
                 unique_identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 vlan_name_id: Optional[pulumi.Input[_builtins.str]] = None,
                 vlan_tag_id: Optional[pulumi.Input[_builtins.int]] = None,
                 voice_domain_permission: Optional[pulumi.Input[_builtins.bool]] = None,
                 web_auth: Optional[pulumi.Input[_builtins.bool]] = None,
                 web_redirection_acl: Optional[pulumi.Input[_builtins.str]] = None,
                 web_redirection_display_certificates_renewal_messages: Optional[pulumi.Input[_builtins.bool]] = None,
                 web_redirection_portal_name: Optional[pulumi.Input[_builtins.str]] = None,
                 web_redirection_static_ip_host_name_fqdn: Optional[pulumi.Input[_builtins.str]] = None,
                 web_redirection_type: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering AuthorizationProfile resources.
        :param pulumi.Input[_builtins.str] access_type: Access type - Choices: `ACCESS_ACCEPT`, `ACCESS_REJECT` - Default value: `ACCESS_ACCEPT`
        :param pulumi.Input[_builtins.str] acl: ACL
        :param pulumi.Input[Sequence[pulumi.Input['AuthorizationProfileAdvancedAttributeArgs']]] advanced_attributes: List of advanced attributes
        :param pulumi.Input[_builtins.bool] agentless_posture: Agentless Posture.
        :param pulumi.Input[_builtins.str] airespace_acl: Airespace ACL
        :param pulumi.Input[_builtins.str] airespace_ipv6_acl: Airespace IPv6 ACL
        :param pulumi.Input[_builtins.str] asa_vpn: ASA VPN
        :param pulumi.Input[_builtins.str] auto_smart_port: Auto smart port
        :param pulumi.Input[_builtins.str] avc_profile: AVC profile
        :param pulumi.Input[_builtins.str] dacl_name: DACL name
        :param pulumi.Input[_builtins.str] description: Description
        :param pulumi.Input[_builtins.bool] easywired_session_candidate: Easy wired session candidate - Default value: `false`
        :param pulumi.Input[_builtins.str] interface_template: Interface template
        :param pulumi.Input[_builtins.str] ipv6_acl_filter: IPv6 ACL
        :param pulumi.Input[_builtins.str] ipv6_dacl_name: IPv6 DACL name
        :param pulumi.Input[_builtins.str] mac_sec_policy: MacSec policy - Choices: `MUST_SECURE`, `MUST_NOT_SECURE`, `SHOULD_SECURE`
        :param pulumi.Input[_builtins.str] name: The name of the authorization profile
        :param pulumi.Input[_builtins.bool] neat: NEAT - Default value: `false`
        :param pulumi.Input[_builtins.str] profile_name: Value needs to be an existing Network Device Profile - Default value: `Cisco`
        :param pulumi.Input[_builtins.str] reauthentication_connectivity: Maintain Connectivity During Reauthentication - Choices: `DEFAULT`, `RADIUS_REQUEST`
        :param pulumi.Input[_builtins.int] reauthentication_timer: Reauthentication timer - Range: `1`-`65535`
        :param pulumi.Input[_builtins.bool] service_template: Service template - Default value: `false`
        :param pulumi.Input[_builtins.bool] track_movement: Track movement - Default value: `false`
        :param pulumi.Input[_builtins.str] unique_identifier: Unique identifier
        :param pulumi.Input[_builtins.str] vlan_name_id: Vlan name or ID
        :param pulumi.Input[_builtins.int] vlan_tag_id: Vlan tag ID - Range: `0`-`31`
        :param pulumi.Input[_builtins.bool] voice_domain_permission: Voice domain permission - Default value: `false`
        :param pulumi.Input[_builtins.bool] web_auth: Web authentication (local) - Default value: `false`
        :param pulumi.Input[_builtins.str] web_redirection_acl: Web redirection ACL
        :param pulumi.Input[_builtins.bool] web_redirection_display_certificates_renewal_messages: This attribute is mandatory when `web_redirection_type` value is `CentralizedWebAuth`. For all other
               `web_redirection_type` values the field must be ignored.
        :param pulumi.Input[_builtins.str] web_redirection_portal_name: A portal that exist in the DB and fits the `web_redirection_type`
        :param pulumi.Input[_builtins.str] web_redirection_static_ip_host_name_fqdn: IP, hostname or FQDN
        :param pulumi.Input[_builtins.str] web_redirection_type: This type must fit the `web_redirection_portal_name` - Choices: `CentralizedWebAuth`, `HotSpot`,
               `NativeSupplicanProvisioning`, `ClientProvisioning`
        """
        if access_type is not None:
            pulumi.set(__self__, "access_type", access_type)
        if acl is not None:
            pulumi.set(__self__, "acl", acl)
        if advanced_attributes is not None:
            pulumi.set(__self__, "advanced_attributes", advanced_attributes)
        if agentless_posture is not None:
            pulumi.set(__self__, "agentless_posture", agentless_posture)
        if airespace_acl is not None:
            pulumi.set(__self__, "airespace_acl", airespace_acl)
        if airespace_ipv6_acl is not None:
            pulumi.set(__self__, "airespace_ipv6_acl", airespace_ipv6_acl)
        if asa_vpn is not None:
            pulumi.set(__self__, "asa_vpn", asa_vpn)
        if auto_smart_port is not None:
            pulumi.set(__self__, "auto_smart_port", auto_smart_port)
        if avc_profile is not None:
            pulumi.set(__self__, "avc_profile", avc_profile)
        if dacl_name is not None:
            pulumi.set(__self__, "dacl_name", dacl_name)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if easywired_session_candidate is not None:
            pulumi.set(__self__, "easywired_session_candidate", easywired_session_candidate)
        if interface_template is not None:
            pulumi.set(__self__, "interface_template", interface_template)
        if ipv6_acl_filter is not None:
            pulumi.set(__self__, "ipv6_acl_filter", ipv6_acl_filter)
        if ipv6_dacl_name is not None:
            pulumi.set(__self__, "ipv6_dacl_name", ipv6_dacl_name)
        if mac_sec_policy is not None:
            pulumi.set(__self__, "mac_sec_policy", mac_sec_policy)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if neat is not None:
            pulumi.set(__self__, "neat", neat)
        if profile_name is not None:
            pulumi.set(__self__, "profile_name", profile_name)
        if reauthentication_connectivity is not None:
            pulumi.set(__self__, "reauthentication_connectivity", reauthentication_connectivity)
        if reauthentication_timer is not None:
            pulumi.set(__self__, "reauthentication_timer", reauthentication_timer)
        if service_template is not None:
            pulumi.set(__self__, "service_template", service_template)
        if track_movement is not None:
            pulumi.set(__self__, "track_movement", track_movement)
        if unique_identifier is not None:
            pulumi.set(__self__, "unique_identifier", unique_identifier)
        if vlan_name_id is not None:
            pulumi.set(__self__, "vlan_name_id", vlan_name_id)
        if vlan_tag_id is not None:
            pulumi.set(__self__, "vlan_tag_id", vlan_tag_id)
        if voice_domain_permission is not None:
            pulumi.set(__self__, "voice_domain_permission", voice_domain_permission)
        if web_auth is not None:
            pulumi.set(__self__, "web_auth", web_auth)
        if web_redirection_acl is not None:
            pulumi.set(__self__, "web_redirection_acl", web_redirection_acl)
        if web_redirection_display_certificates_renewal_messages is not None:
            pulumi.set(__self__, "web_redirection_display_certificates_renewal_messages", web_redirection_display_certificates_renewal_messages)
        if web_redirection_portal_name is not None:
            pulumi.set(__self__, "web_redirection_portal_name", web_redirection_portal_name)
        if web_redirection_static_ip_host_name_fqdn is not None:
            pulumi.set(__self__, "web_redirection_static_ip_host_name_fqdn", web_redirection_static_ip_host_name_fqdn)
        if web_redirection_type is not None:
            pulumi.set(__self__, "web_redirection_type", web_redirection_type)

    @_builtins.property
    @pulumi.getter(name="accessType")
    def access_type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Access type - Choices: `ACCESS_ACCEPT`, `ACCESS_REJECT` - Default value: `ACCESS_ACCEPT`
        """
        return pulumi.get(self, "access_type")

    @access_type.setter
    def access_type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "access_type", value)

    @_builtins.property
    @pulumi.getter
    def acl(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        ACL
        """
        return pulumi.get(self, "acl")

    @acl.setter
    def acl(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "acl", value)

    @_builtins.property
    @pulumi.getter(name="advancedAttributes")
    def advanced_attributes(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['AuthorizationProfileAdvancedAttributeArgs']]]]:
        """
        List of advanced attributes
        """
        return pulumi.get(self, "advanced_attributes")

    @advanced_attributes.setter
    def advanced_attributes(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['AuthorizationProfileAdvancedAttributeArgs']]]]):
        pulumi.set(self, "advanced_attributes", value)

    @_builtins.property
    @pulumi.getter(name="agentlessPosture")
    def agentless_posture(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Agentless Posture.
        """
        return pulumi.get(self, "agentless_posture")

    @agentless_posture.setter
    def agentless_posture(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "agentless_posture", value)

    @_builtins.property
    @pulumi.getter(name="airespaceAcl")
    def airespace_acl(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Airespace ACL
        """
        return pulumi.get(self, "airespace_acl")

    @airespace_acl.setter
    def airespace_acl(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "airespace_acl", value)

    @_builtins.property
    @pulumi.getter(name="airespaceIpv6Acl")
    def airespace_ipv6_acl(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Airespace IPv6 ACL
        """
        return pulumi.get(self, "airespace_ipv6_acl")

    @airespace_ipv6_acl.setter
    def airespace_ipv6_acl(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "airespace_ipv6_acl", value)

    @_builtins.property
    @pulumi.getter(name="asaVpn")
    def asa_vpn(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        ASA VPN
        """
        return pulumi.get(self, "asa_vpn")

    @asa_vpn.setter
    def asa_vpn(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "asa_vpn", value)

    @_builtins.property
    @pulumi.getter(name="autoSmartPort")
    def auto_smart_port(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Auto smart port
        """
        return pulumi.get(self, "auto_smart_port")

    @auto_smart_port.setter
    def auto_smart_port(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "auto_smart_port", value)

    @_builtins.property
    @pulumi.getter(name="avcProfile")
    def avc_profile(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        AVC profile
        """
        return pulumi.get(self, "avc_profile")

    @avc_profile.setter
    def avc_profile(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "avc_profile", value)

    @_builtins.property
    @pulumi.getter(name="daclName")
    def dacl_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        DACL name
        """
        return pulumi.get(self, "dacl_name")

    @dacl_name.setter
    def dacl_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "dacl_name", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Description
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter(name="easywiredSessionCandidate")
    def easywired_session_candidate(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Easy wired session candidate - Default value: `false`
        """
        return pulumi.get(self, "easywired_session_candidate")

    @easywired_session_candidate.setter
    def easywired_session_candidate(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "easywired_session_candidate", value)

    @_builtins.property
    @pulumi.getter(name="interfaceTemplate")
    def interface_template(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Interface template
        """
        return pulumi.get(self, "interface_template")

    @interface_template.setter
    def interface_template(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "interface_template", value)

    @_builtins.property
    @pulumi.getter(name="ipv6AclFilter")
    def ipv6_acl_filter(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        IPv6 ACL
        """
        return pulumi.get(self, "ipv6_acl_filter")

    @ipv6_acl_filter.setter
    def ipv6_acl_filter(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "ipv6_acl_filter", value)

    @_builtins.property
    @pulumi.getter(name="ipv6DaclName")
    def ipv6_dacl_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        IPv6 DACL name
        """
        return pulumi.get(self, "ipv6_dacl_name")

    @ipv6_dacl_name.setter
    def ipv6_dacl_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "ipv6_dacl_name", value)

    @_builtins.property
    @pulumi.getter(name="macSecPolicy")
    def mac_sec_policy(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        MacSec policy - Choices: `MUST_SECURE`, `MUST_NOT_SECURE`, `SHOULD_SECURE`
        """
        return pulumi.get(self, "mac_sec_policy")

    @mac_sec_policy.setter
    def mac_sec_policy(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "mac_sec_policy", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the authorization profile
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def neat(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        NEAT - Default value: `false`
        """
        return pulumi.get(self, "neat")

    @neat.setter
    def neat(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "neat", value)

    @_builtins.property
    @pulumi.getter(name="profileName")
    def profile_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Value needs to be an existing Network Device Profile - Default value: `Cisco`
        """
        return pulumi.get(self, "profile_name")

    @profile_name.setter
    def profile_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "profile_name", value)

    @_builtins.property
    @pulumi.getter(name="reauthenticationConnectivity")
    def reauthentication_connectivity(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Maintain Connectivity During Reauthentication - Choices: `DEFAULT`, `RADIUS_REQUEST`
        """
        return pulumi.get(self, "reauthentication_connectivity")

    @reauthentication_connectivity.setter
    def reauthentication_connectivity(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "reauthentication_connectivity", value)

    @_builtins.property
    @pulumi.getter(name="reauthenticationTimer")
    def reauthentication_timer(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Reauthentication timer - Range: `1`-`65535`
        """
        return pulumi.get(self, "reauthentication_timer")

    @reauthentication_timer.setter
    def reauthentication_timer(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "reauthentication_timer", value)

    @_builtins.property
    @pulumi.getter(name="serviceTemplate")
    def service_template(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Service template - Default value: `false`
        """
        return pulumi.get(self, "service_template")

    @service_template.setter
    def service_template(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "service_template", value)

    @_builtins.property
    @pulumi.getter(name="trackMovement")
    def track_movement(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Track movement - Default value: `false`
        """
        return pulumi.get(self, "track_movement")

    @track_movement.setter
    def track_movement(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "track_movement", value)

    @_builtins.property
    @pulumi.getter(name="uniqueIdentifier")
    def unique_identifier(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique identifier
        """
        return pulumi.get(self, "unique_identifier")

    @unique_identifier.setter
    def unique_identifier(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "unique_identifier", value)

    @_builtins.property
    @pulumi.getter(name="vlanNameId")
    def vlan_name_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Vlan name or ID
        """
        return pulumi.get(self, "vlan_name_id")

    @vlan_name_id.setter
    def vlan_name_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "vlan_name_id", value)

    @_builtins.property
    @pulumi.getter(name="vlanTagId")
    def vlan_tag_id(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Vlan tag ID - Range: `0`-`31`
        """
        return pulumi.get(self, "vlan_tag_id")

    @vlan_tag_id.setter
    def vlan_tag_id(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "vlan_tag_id", value)

    @_builtins.property
    @pulumi.getter(name="voiceDomainPermission")
    def voice_domain_permission(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Voice domain permission - Default value: `false`
        """
        return pulumi.get(self, "voice_domain_permission")

    @voice_domain_permission.setter
    def voice_domain_permission(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "voice_domain_permission", value)

    @_builtins.property
    @pulumi.getter(name="webAuth")
    def web_auth(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Web authentication (local) - Default value: `false`
        """
        return pulumi.get(self, "web_auth")

    @web_auth.setter
    def web_auth(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "web_auth", value)

    @_builtins.property
    @pulumi.getter(name="webRedirectionAcl")
    def web_redirection_acl(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Web redirection ACL
        """
        return pulumi.get(self, "web_redirection_acl")

    @web_redirection_acl.setter
    def web_redirection_acl(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "web_redirection_acl", value)

    @_builtins.property
    @pulumi.getter(name="webRedirectionDisplayCertificatesRenewalMessages")
    def web_redirection_display_certificates_renewal_messages(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        This attribute is mandatory when `web_redirection_type` value is `CentralizedWebAuth`. For all other
        `web_redirection_type` values the field must be ignored.
        """
        return pulumi.get(self, "web_redirection_display_certificates_renewal_messages")

    @web_redirection_display_certificates_renewal_messages.setter
    def web_redirection_display_certificates_renewal_messages(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "web_redirection_display_certificates_renewal_messages", value)

    @_builtins.property
    @pulumi.getter(name="webRedirectionPortalName")
    def web_redirection_portal_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        A portal that exist in the DB and fits the `web_redirection_type`
        """
        return pulumi.get(self, "web_redirection_portal_name")

    @web_redirection_portal_name.setter
    def web_redirection_portal_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "web_redirection_portal_name", value)

    @_builtins.property
    @pulumi.getter(name="webRedirectionStaticIpHostNameFqdn")
    def web_redirection_static_ip_host_name_fqdn(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        IP, hostname or FQDN
        """
        return pulumi.get(self, "web_redirection_static_ip_host_name_fqdn")

    @web_redirection_static_ip_host_name_fqdn.setter
    def web_redirection_static_ip_host_name_fqdn(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "web_redirection_static_ip_host_name_fqdn", value)

    @_builtins.property
    @pulumi.getter(name="webRedirectionType")
    def web_redirection_type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        This type must fit the `web_redirection_portal_name` - Choices: `CentralizedWebAuth`, `HotSpot`,
        `NativeSupplicanProvisioning`, `ClientProvisioning`
        """
        return pulumi.get(self, "web_redirection_type")

    @web_redirection_type.setter
    def web_redirection_type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "web_redirection_type", value)


@pulumi.type_token("ise:networkaccess/authorizationProfile:AuthorizationProfile")
class AuthorizationProfile(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 access_type: Optional[pulumi.Input[_builtins.str]] = None,
                 acl: Optional[pulumi.Input[_builtins.str]] = None,
                 advanced_attributes: Optional[pulumi.Input[Sequence[pulumi.Input[Union['AuthorizationProfileAdvancedAttributeArgs', 'AuthorizationProfileAdvancedAttributeArgsDict']]]]] = None,
                 agentless_posture: Optional[pulumi.Input[_builtins.bool]] = None,
                 airespace_acl: Optional[pulumi.Input[_builtins.str]] = None,
                 airespace_ipv6_acl: Optional[pulumi.Input[_builtins.str]] = None,
                 asa_vpn: Optional[pulumi.Input[_builtins.str]] = None,
                 auto_smart_port: Optional[pulumi.Input[_builtins.str]] = None,
                 avc_profile: Optional[pulumi.Input[_builtins.str]] = None,
                 dacl_name: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 easywired_session_candidate: Optional[pulumi.Input[_builtins.bool]] = None,
                 interface_template: Optional[pulumi.Input[_builtins.str]] = None,
                 ipv6_acl_filter: Optional[pulumi.Input[_builtins.str]] = None,
                 ipv6_dacl_name: Optional[pulumi.Input[_builtins.str]] = None,
                 mac_sec_policy: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 neat: Optional[pulumi.Input[_builtins.bool]] = None,
                 profile_name: Optional[pulumi.Input[_builtins.str]] = None,
                 reauthentication_connectivity: Optional[pulumi.Input[_builtins.str]] = None,
                 reauthentication_timer: Optional[pulumi.Input[_builtins.int]] = None,
                 service_template: Optional[pulumi.Input[_builtins.bool]] = None,
                 track_movement: Optional[pulumi.Input[_builtins.bool]] = None,
                 unique_identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 vlan_name_id: Optional[pulumi.Input[_builtins.str]] = None,
                 vlan_tag_id: Optional[pulumi.Input[_builtins.int]] = None,
                 voice_domain_permission: Optional[pulumi.Input[_builtins.bool]] = None,
                 web_auth: Optional[pulumi.Input[_builtins.bool]] = None,
                 web_redirection_acl: Optional[pulumi.Input[_builtins.str]] = None,
                 web_redirection_display_certificates_renewal_messages: Optional[pulumi.Input[_builtins.bool]] = None,
                 web_redirection_portal_name: Optional[pulumi.Input[_builtins.str]] = None,
                 web_redirection_static_ip_host_name_fqdn: Optional[pulumi.Input[_builtins.str]] = None,
                 web_redirection_type: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        This resource can manage an authorization profiles policy element.

        ## Import

        The `pulumi import` command can be used, for example:

        ```sh
        $ pulumi import ise:networkaccess/authorizationProfile:AuthorizationProfile example "76d24097-41c4-4558-a4d0-a8c07ac08470"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] access_type: Access type - Choices: `ACCESS_ACCEPT`, `ACCESS_REJECT` - Default value: `ACCESS_ACCEPT`
        :param pulumi.Input[_builtins.str] acl: ACL
        :param pulumi.Input[Sequence[pulumi.Input[Union['AuthorizationProfileAdvancedAttributeArgs', 'AuthorizationProfileAdvancedAttributeArgsDict']]]] advanced_attributes: List of advanced attributes
        :param pulumi.Input[_builtins.bool] agentless_posture: Agentless Posture.
        :param pulumi.Input[_builtins.str] airespace_acl: Airespace ACL
        :param pulumi.Input[_builtins.str] airespace_ipv6_acl: Airespace IPv6 ACL
        :param pulumi.Input[_builtins.str] asa_vpn: ASA VPN
        :param pulumi.Input[_builtins.str] auto_smart_port: Auto smart port
        :param pulumi.Input[_builtins.str] avc_profile: AVC profile
        :param pulumi.Input[_builtins.str] dacl_name: DACL name
        :param pulumi.Input[_builtins.str] description: Description
        :param pulumi.Input[_builtins.bool] easywired_session_candidate: Easy wired session candidate - Default value: `false`
        :param pulumi.Input[_builtins.str] interface_template: Interface template
        :param pulumi.Input[_builtins.str] ipv6_acl_filter: IPv6 ACL
        :param pulumi.Input[_builtins.str] ipv6_dacl_name: IPv6 DACL name
        :param pulumi.Input[_builtins.str] mac_sec_policy: MacSec policy - Choices: `MUST_SECURE`, `MUST_NOT_SECURE`, `SHOULD_SECURE`
        :param pulumi.Input[_builtins.str] name: The name of the authorization profile
        :param pulumi.Input[_builtins.bool] neat: NEAT - Default value: `false`
        :param pulumi.Input[_builtins.str] profile_name: Value needs to be an existing Network Device Profile - Default value: `Cisco`
        :param pulumi.Input[_builtins.str] reauthentication_connectivity: Maintain Connectivity During Reauthentication - Choices: `DEFAULT`, `RADIUS_REQUEST`
        :param pulumi.Input[_builtins.int] reauthentication_timer: Reauthentication timer - Range: `1`-`65535`
        :param pulumi.Input[_builtins.bool] service_template: Service template - Default value: `false`
        :param pulumi.Input[_builtins.bool] track_movement: Track movement - Default value: `false`
        :param pulumi.Input[_builtins.str] unique_identifier: Unique identifier
        :param pulumi.Input[_builtins.str] vlan_name_id: Vlan name or ID
        :param pulumi.Input[_builtins.int] vlan_tag_id: Vlan tag ID - Range: `0`-`31`
        :param pulumi.Input[_builtins.bool] voice_domain_permission: Voice domain permission - Default value: `false`
        :param pulumi.Input[_builtins.bool] web_auth: Web authentication (local) - Default value: `false`
        :param pulumi.Input[_builtins.str] web_redirection_acl: Web redirection ACL
        :param pulumi.Input[_builtins.bool] web_redirection_display_certificates_renewal_messages: This attribute is mandatory when `web_redirection_type` value is `CentralizedWebAuth`. For all other
               `web_redirection_type` values the field must be ignored.
        :param pulumi.Input[_builtins.str] web_redirection_portal_name: A portal that exist in the DB and fits the `web_redirection_type`
        :param pulumi.Input[_builtins.str] web_redirection_static_ip_host_name_fqdn: IP, hostname or FQDN
        :param pulumi.Input[_builtins.str] web_redirection_type: This type must fit the `web_redirection_portal_name` - Choices: `CentralizedWebAuth`, `HotSpot`,
               `NativeSupplicanProvisioning`, `ClientProvisioning`
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[AuthorizationProfileArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        This resource can manage an authorization profiles policy element.

        ## Import

        The `pulumi import` command can be used, for example:

        ```sh
        $ pulumi import ise:networkaccess/authorizationProfile:AuthorizationProfile example "76d24097-41c4-4558-a4d0-a8c07ac08470"
        ```

        :param str resource_name: The name of the resource.
        :param AuthorizationProfileArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(AuthorizationProfileArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 access_type: Optional[pulumi.Input[_builtins.str]] = None,
                 acl: Optional[pulumi.Input[_builtins.str]] = None,
                 advanced_attributes: Optional[pulumi.Input[Sequence[pulumi.Input[Union['AuthorizationProfileAdvancedAttributeArgs', 'AuthorizationProfileAdvancedAttributeArgsDict']]]]] = None,
                 agentless_posture: Optional[pulumi.Input[_builtins.bool]] = None,
                 airespace_acl: Optional[pulumi.Input[_builtins.str]] = None,
                 airespace_ipv6_acl: Optional[pulumi.Input[_builtins.str]] = None,
                 asa_vpn: Optional[pulumi.Input[_builtins.str]] = None,
                 auto_smart_port: Optional[pulumi.Input[_builtins.str]] = None,
                 avc_profile: Optional[pulumi.Input[_builtins.str]] = None,
                 dacl_name: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 easywired_session_candidate: Optional[pulumi.Input[_builtins.bool]] = None,
                 interface_template: Optional[pulumi.Input[_builtins.str]] = None,
                 ipv6_acl_filter: Optional[pulumi.Input[_builtins.str]] = None,
                 ipv6_dacl_name: Optional[pulumi.Input[_builtins.str]] = None,
                 mac_sec_policy: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 neat: Optional[pulumi.Input[_builtins.bool]] = None,
                 profile_name: Optional[pulumi.Input[_builtins.str]] = None,
                 reauthentication_connectivity: Optional[pulumi.Input[_builtins.str]] = None,
                 reauthentication_timer: Optional[pulumi.Input[_builtins.int]] = None,
                 service_template: Optional[pulumi.Input[_builtins.bool]] = None,
                 track_movement: Optional[pulumi.Input[_builtins.bool]] = None,
                 unique_identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 vlan_name_id: Optional[pulumi.Input[_builtins.str]] = None,
                 vlan_tag_id: Optional[pulumi.Input[_builtins.int]] = None,
                 voice_domain_permission: Optional[pulumi.Input[_builtins.bool]] = None,
                 web_auth: Optional[pulumi.Input[_builtins.bool]] = None,
                 web_redirection_acl: Optional[pulumi.Input[_builtins.str]] = None,
                 web_redirection_display_certificates_renewal_messages: Optional[pulumi.Input[_builtins.bool]] = None,
                 web_redirection_portal_name: Optional[pulumi.Input[_builtins.str]] = None,
                 web_redirection_static_ip_host_name_fqdn: Optional[pulumi.Input[_builtins.str]] = None,
                 web_redirection_type: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = AuthorizationProfileArgs.__new__(AuthorizationProfileArgs)

            __props__.__dict__["access_type"] = access_type
            __props__.__dict__["acl"] = acl
            __props__.__dict__["advanced_attributes"] = advanced_attributes
            __props__.__dict__["agentless_posture"] = agentless_posture
            __props__.__dict__["airespace_acl"] = airespace_acl
            __props__.__dict__["airespace_ipv6_acl"] = airespace_ipv6_acl
            __props__.__dict__["asa_vpn"] = asa_vpn
            __props__.__dict__["auto_smart_port"] = auto_smart_port
            __props__.__dict__["avc_profile"] = avc_profile
            __props__.__dict__["dacl_name"] = dacl_name
            __props__.__dict__["description"] = description
            __props__.__dict__["easywired_session_candidate"] = easywired_session_candidate
            __props__.__dict__["interface_template"] = interface_template
            __props__.__dict__["ipv6_acl_filter"] = ipv6_acl_filter
            __props__.__dict__["ipv6_dacl_name"] = ipv6_dacl_name
            __props__.__dict__["mac_sec_policy"] = mac_sec_policy
            __props__.__dict__["name"] = name
            __props__.__dict__["neat"] = neat
            __props__.__dict__["profile_name"] = profile_name
            __props__.__dict__["reauthentication_connectivity"] = reauthentication_connectivity
            __props__.__dict__["reauthentication_timer"] = reauthentication_timer
            __props__.__dict__["service_template"] = service_template
            __props__.__dict__["track_movement"] = track_movement
            __props__.__dict__["unique_identifier"] = unique_identifier
            __props__.__dict__["vlan_name_id"] = vlan_name_id
            __props__.__dict__["vlan_tag_id"] = vlan_tag_id
            __props__.__dict__["voice_domain_permission"] = voice_domain_permission
            __props__.__dict__["web_auth"] = web_auth
            __props__.__dict__["web_redirection_acl"] = web_redirection_acl
            __props__.__dict__["web_redirection_display_certificates_renewal_messages"] = web_redirection_display_certificates_renewal_messages
            __props__.__dict__["web_redirection_portal_name"] = web_redirection_portal_name
            __props__.__dict__["web_redirection_static_ip_host_name_fqdn"] = web_redirection_static_ip_host_name_fqdn
            __props__.__dict__["web_redirection_type"] = web_redirection_type
        super(AuthorizationProfile, __self__).__init__(
            'ise:networkaccess/authorizationProfile:AuthorizationProfile',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            access_type: Optional[pulumi.Input[_builtins.str]] = None,
            acl: Optional[pulumi.Input[_builtins.str]] = None,
            advanced_attributes: Optional[pulumi.Input[Sequence[pulumi.Input[Union['AuthorizationProfileAdvancedAttributeArgs', 'AuthorizationProfileAdvancedAttributeArgsDict']]]]] = None,
            agentless_posture: Optional[pulumi.Input[_builtins.bool]] = None,
            airespace_acl: Optional[pulumi.Input[_builtins.str]] = None,
            airespace_ipv6_acl: Optional[pulumi.Input[_builtins.str]] = None,
            asa_vpn: Optional[pulumi.Input[_builtins.str]] = None,
            auto_smart_port: Optional[pulumi.Input[_builtins.str]] = None,
            avc_profile: Optional[pulumi.Input[_builtins.str]] = None,
            dacl_name: Optional[pulumi.Input[_builtins.str]] = None,
            description: Optional[pulumi.Input[_builtins.str]] = None,
            easywired_session_candidate: Optional[pulumi.Input[_builtins.bool]] = None,
            interface_template: Optional[pulumi.Input[_builtins.str]] = None,
            ipv6_acl_filter: Optional[pulumi.Input[_builtins.str]] = None,
            ipv6_dacl_name: Optional[pulumi.Input[_builtins.str]] = None,
            mac_sec_policy: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            neat: Optional[pulumi.Input[_builtins.bool]] = None,
            profile_name: Optional[pulumi.Input[_builtins.str]] = None,
            reauthentication_connectivity: Optional[pulumi.Input[_builtins.str]] = None,
            reauthentication_timer: Optional[pulumi.Input[_builtins.int]] = None,
            service_template: Optional[pulumi.Input[_builtins.bool]] = None,
            track_movement: Optional[pulumi.Input[_builtins.bool]] = None,
            unique_identifier: Optional[pulumi.Input[_builtins.str]] = None,
            vlan_name_id: Optional[pulumi.Input[_builtins.str]] = None,
            vlan_tag_id: Optional[pulumi.Input[_builtins.int]] = None,
            voice_domain_permission: Optional[pulumi.Input[_builtins.bool]] = None,
            web_auth: Optional[pulumi.Input[_builtins.bool]] = None,
            web_redirection_acl: Optional[pulumi.Input[_builtins.str]] = None,
            web_redirection_display_certificates_renewal_messages: Optional[pulumi.Input[_builtins.bool]] = None,
            web_redirection_portal_name: Optional[pulumi.Input[_builtins.str]] = None,
            web_redirection_static_ip_host_name_fqdn: Optional[pulumi.Input[_builtins.str]] = None,
            web_redirection_type: Optional[pulumi.Input[_builtins.str]] = None) -> 'AuthorizationProfile':
        """
        Get an existing AuthorizationProfile resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] access_type: Access type - Choices: `ACCESS_ACCEPT`, `ACCESS_REJECT` - Default value: `ACCESS_ACCEPT`
        :param pulumi.Input[_builtins.str] acl: ACL
        :param pulumi.Input[Sequence[pulumi.Input[Union['AuthorizationProfileAdvancedAttributeArgs', 'AuthorizationProfileAdvancedAttributeArgsDict']]]] advanced_attributes: List of advanced attributes
        :param pulumi.Input[_builtins.bool] agentless_posture: Agentless Posture.
        :param pulumi.Input[_builtins.str] airespace_acl: Airespace ACL
        :param pulumi.Input[_builtins.str] airespace_ipv6_acl: Airespace IPv6 ACL
        :param pulumi.Input[_builtins.str] asa_vpn: ASA VPN
        :param pulumi.Input[_builtins.str] auto_smart_port: Auto smart port
        :param pulumi.Input[_builtins.str] avc_profile: AVC profile
        :param pulumi.Input[_builtins.str] dacl_name: DACL name
        :param pulumi.Input[_builtins.str] description: Description
        :param pulumi.Input[_builtins.bool] easywired_session_candidate: Easy wired session candidate - Default value: `false`
        :param pulumi.Input[_builtins.str] interface_template: Interface template
        :param pulumi.Input[_builtins.str] ipv6_acl_filter: IPv6 ACL
        :param pulumi.Input[_builtins.str] ipv6_dacl_name: IPv6 DACL name
        :param pulumi.Input[_builtins.str] mac_sec_policy: MacSec policy - Choices: `MUST_SECURE`, `MUST_NOT_SECURE`, `SHOULD_SECURE`
        :param pulumi.Input[_builtins.str] name: The name of the authorization profile
        :param pulumi.Input[_builtins.bool] neat: NEAT - Default value: `false`
        :param pulumi.Input[_builtins.str] profile_name: Value needs to be an existing Network Device Profile - Default value: `Cisco`
        :param pulumi.Input[_builtins.str] reauthentication_connectivity: Maintain Connectivity During Reauthentication - Choices: `DEFAULT`, `RADIUS_REQUEST`
        :param pulumi.Input[_builtins.int] reauthentication_timer: Reauthentication timer - Range: `1`-`65535`
        :param pulumi.Input[_builtins.bool] service_template: Service template - Default value: `false`
        :param pulumi.Input[_builtins.bool] track_movement: Track movement - Default value: `false`
        :param pulumi.Input[_builtins.str] unique_identifier: Unique identifier
        :param pulumi.Input[_builtins.str] vlan_name_id: Vlan name or ID
        :param pulumi.Input[_builtins.int] vlan_tag_id: Vlan tag ID - Range: `0`-`31`
        :param pulumi.Input[_builtins.bool] voice_domain_permission: Voice domain permission - Default value: `false`
        :param pulumi.Input[_builtins.bool] web_auth: Web authentication (local) - Default value: `false`
        :param pulumi.Input[_builtins.str] web_redirection_acl: Web redirection ACL
        :param pulumi.Input[_builtins.bool] web_redirection_display_certificates_renewal_messages: This attribute is mandatory when `web_redirection_type` value is `CentralizedWebAuth`. For all other
               `web_redirection_type` values the field must be ignored.
        :param pulumi.Input[_builtins.str] web_redirection_portal_name: A portal that exist in the DB and fits the `web_redirection_type`
        :param pulumi.Input[_builtins.str] web_redirection_static_ip_host_name_fqdn: IP, hostname or FQDN
        :param pulumi.Input[_builtins.str] web_redirection_type: This type must fit the `web_redirection_portal_name` - Choices: `CentralizedWebAuth`, `HotSpot`,
               `NativeSupplicanProvisioning`, `ClientProvisioning`
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _AuthorizationProfileState.__new__(_AuthorizationProfileState)

        __props__.__dict__["access_type"] = access_type
        __props__.__dict__["acl"] = acl
        __props__.__dict__["advanced_attributes"] = advanced_attributes
        __props__.__dict__["agentless_posture"] = agentless_posture
        __props__.__dict__["airespace_acl"] = airespace_acl
        __props__.__dict__["airespace_ipv6_acl"] = airespace_ipv6_acl
        __props__.__dict__["asa_vpn"] = asa_vpn
        __props__.__dict__["auto_smart_port"] = auto_smart_port
        __props__.__dict__["avc_profile"] = avc_profile
        __props__.__dict__["dacl_name"] = dacl_name
        __props__.__dict__["description"] = description
        __props__.__dict__["easywired_session_candidate"] = easywired_session_candidate
        __props__.__dict__["interface_template"] = interface_template
        __props__.__dict__["ipv6_acl_filter"] = ipv6_acl_filter
        __props__.__dict__["ipv6_dacl_name"] = ipv6_dacl_name
        __props__.__dict__["mac_sec_policy"] = mac_sec_policy
        __props__.__dict__["name"] = name
        __props__.__dict__["neat"] = neat
        __props__.__dict__["profile_name"] = profile_name
        __props__.__dict__["reauthentication_connectivity"] = reauthentication_connectivity
        __props__.__dict__["reauthentication_timer"] = reauthentication_timer
        __props__.__dict__["service_template"] = service_template
        __props__.__dict__["track_movement"] = track_movement
        __props__.__dict__["unique_identifier"] = unique_identifier
        __props__.__dict__["vlan_name_id"] = vlan_name_id
        __props__.__dict__["vlan_tag_id"] = vlan_tag_id
        __props__.__dict__["voice_domain_permission"] = voice_domain_permission
        __props__.__dict__["web_auth"] = web_auth
        __props__.__dict__["web_redirection_acl"] = web_redirection_acl
        __props__.__dict__["web_redirection_display_certificates_renewal_messages"] = web_redirection_display_certificates_renewal_messages
        __props__.__dict__["web_redirection_portal_name"] = web_redirection_portal_name
        __props__.__dict__["web_redirection_static_ip_host_name_fqdn"] = web_redirection_static_ip_host_name_fqdn
        __props__.__dict__["web_redirection_type"] = web_redirection_type
        return AuthorizationProfile(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="accessType")
    def access_type(self) -> pulumi.Output[_builtins.str]:
        """
        Access type - Choices: `ACCESS_ACCEPT`, `ACCESS_REJECT` - Default value: `ACCESS_ACCEPT`
        """
        return pulumi.get(self, "access_type")

    @_builtins.property
    @pulumi.getter
    def acl(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        ACL
        """
        return pulumi.get(self, "acl")

    @_builtins.property
    @pulumi.getter(name="advancedAttributes")
    def advanced_attributes(self) -> pulumi.Output[Optional[Sequence['outputs.AuthorizationProfileAdvancedAttribute']]]:
        """
        List of advanced attributes
        """
        return pulumi.get(self, "advanced_attributes")

    @_builtins.property
    @pulumi.getter(name="agentlessPosture")
    def agentless_posture(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Agentless Posture.
        """
        return pulumi.get(self, "agentless_posture")

    @_builtins.property
    @pulumi.getter(name="airespaceAcl")
    def airespace_acl(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Airespace ACL
        """
        return pulumi.get(self, "airespace_acl")

    @_builtins.property
    @pulumi.getter(name="airespaceIpv6Acl")
    def airespace_ipv6_acl(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Airespace IPv6 ACL
        """
        return pulumi.get(self, "airespace_ipv6_acl")

    @_builtins.property
    @pulumi.getter(name="asaVpn")
    def asa_vpn(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        ASA VPN
        """
        return pulumi.get(self, "asa_vpn")

    @_builtins.property
    @pulumi.getter(name="autoSmartPort")
    def auto_smart_port(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Auto smart port
        """
        return pulumi.get(self, "auto_smart_port")

    @_builtins.property
    @pulumi.getter(name="avcProfile")
    def avc_profile(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        AVC profile
        """
        return pulumi.get(self, "avc_profile")

    @_builtins.property
    @pulumi.getter(name="daclName")
    def dacl_name(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        DACL name
        """
        return pulumi.get(self, "dacl_name")

    @_builtins.property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Description
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter(name="easywiredSessionCandidate")
    def easywired_session_candidate(self) -> pulumi.Output[_builtins.bool]:
        """
        Easy wired session candidate - Default value: `false`
        """
        return pulumi.get(self, "easywired_session_candidate")

    @_builtins.property
    @pulumi.getter(name="interfaceTemplate")
    def interface_template(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Interface template
        """
        return pulumi.get(self, "interface_template")

    @_builtins.property
    @pulumi.getter(name="ipv6AclFilter")
    def ipv6_acl_filter(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        IPv6 ACL
        """
        return pulumi.get(self, "ipv6_acl_filter")

    @_builtins.property
    @pulumi.getter(name="ipv6DaclName")
    def ipv6_dacl_name(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        IPv6 DACL name
        """
        return pulumi.get(self, "ipv6_dacl_name")

    @_builtins.property
    @pulumi.getter(name="macSecPolicy")
    def mac_sec_policy(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        MacSec policy - Choices: `MUST_SECURE`, `MUST_NOT_SECURE`, `SHOULD_SECURE`
        """
        return pulumi.get(self, "mac_sec_policy")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        The name of the authorization profile
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def neat(self) -> pulumi.Output[_builtins.bool]:
        """
        NEAT - Default value: `false`
        """
        return pulumi.get(self, "neat")

    @_builtins.property
    @pulumi.getter(name="profileName")
    def profile_name(self) -> pulumi.Output[_builtins.str]:
        """
        Value needs to be an existing Network Device Profile - Default value: `Cisco`
        """
        return pulumi.get(self, "profile_name")

    @_builtins.property
    @pulumi.getter(name="reauthenticationConnectivity")
    def reauthentication_connectivity(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Maintain Connectivity During Reauthentication - Choices: `DEFAULT`, `RADIUS_REQUEST`
        """
        return pulumi.get(self, "reauthentication_connectivity")

    @_builtins.property
    @pulumi.getter(name="reauthenticationTimer")
    def reauthentication_timer(self) -> pulumi.Output[Optional[_builtins.int]]:
        """
        Reauthentication timer - Range: `1`-`65535`
        """
        return pulumi.get(self, "reauthentication_timer")

    @_builtins.property
    @pulumi.getter(name="serviceTemplate")
    def service_template(self) -> pulumi.Output[_builtins.bool]:
        """
        Service template - Default value: `false`
        """
        return pulumi.get(self, "service_template")

    @_builtins.property
    @pulumi.getter(name="trackMovement")
    def track_movement(self) -> pulumi.Output[_builtins.bool]:
        """
        Track movement - Default value: `false`
        """
        return pulumi.get(self, "track_movement")

    @_builtins.property
    @pulumi.getter(name="uniqueIdentifier")
    def unique_identifier(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Unique identifier
        """
        return pulumi.get(self, "unique_identifier")

    @_builtins.property
    @pulumi.getter(name="vlanNameId")
    def vlan_name_id(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Vlan name or ID
        """
        return pulumi.get(self, "vlan_name_id")

    @_builtins.property
    @pulumi.getter(name="vlanTagId")
    def vlan_tag_id(self) -> pulumi.Output[Optional[_builtins.int]]:
        """
        Vlan tag ID - Range: `0`-`31`
        """
        return pulumi.get(self, "vlan_tag_id")

    @_builtins.property
    @pulumi.getter(name="voiceDomainPermission")
    def voice_domain_permission(self) -> pulumi.Output[_builtins.bool]:
        """
        Voice domain permission - Default value: `false`
        """
        return pulumi.get(self, "voice_domain_permission")

    @_builtins.property
    @pulumi.getter(name="webAuth")
    def web_auth(self) -> pulumi.Output[_builtins.bool]:
        """
        Web authentication (local) - Default value: `false`
        """
        return pulumi.get(self, "web_auth")

    @_builtins.property
    @pulumi.getter(name="webRedirectionAcl")
    def web_redirection_acl(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Web redirection ACL
        """
        return pulumi.get(self, "web_redirection_acl")

    @_builtins.property
    @pulumi.getter(name="webRedirectionDisplayCertificatesRenewalMessages")
    def web_redirection_display_certificates_renewal_messages(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        This attribute is mandatory when `web_redirection_type` value is `CentralizedWebAuth`. For all other
        `web_redirection_type` values the field must be ignored.
        """
        return pulumi.get(self, "web_redirection_display_certificates_renewal_messages")

    @_builtins.property
    @pulumi.getter(name="webRedirectionPortalName")
    def web_redirection_portal_name(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        A portal that exist in the DB and fits the `web_redirection_type`
        """
        return pulumi.get(self, "web_redirection_portal_name")

    @_builtins.property
    @pulumi.getter(name="webRedirectionStaticIpHostNameFqdn")
    def web_redirection_static_ip_host_name_fqdn(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        IP, hostname or FQDN
        """
        return pulumi.get(self, "web_redirection_static_ip_host_name_fqdn")

    @_builtins.property
    @pulumi.getter(name="webRedirectionType")
    def web_redirection_type(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        This type must fit the `web_redirection_portal_name` - Choices: `CentralizedWebAuth`, `HotSpot`,
        `NativeSupplicanProvisioning`, `ClientProvisioning`
        """
        return pulumi.get(self, "web_redirection_type")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetRepositoryResult',
    'AwaitableGetRepositoryResult',
    'get_repository',
    'get_repository_output',
]

@pulumi.output_type
class GetRepositoryResult:
    """
    A collection of values returned by getRepository.
    """
    def __init__(__self__, enable_pki=None, id=None, name=None, password=None, path=None, protocol=None, server_name=None, user_name=None):
        if enable_pki and not isinstance(enable_pki, bool):
            raise TypeError("Expected argument 'enable_pki' to be a bool")
        pulumi.set(__self__, "enable_pki", enable_pki)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if password and not isinstance(password, str):
            raise TypeError("Expected argument 'password' to be a str")
        pulumi.set(__self__, "password", password)
        if path and not isinstance(path, str):
            raise TypeError("Expected argument 'path' to be a str")
        pulumi.set(__self__, "path", path)
        if protocol and not isinstance(protocol, str):
            raise TypeError("Expected argument 'protocol' to be a str")
        pulumi.set(__self__, "protocol", protocol)
        if server_name and not isinstance(server_name, str):
            raise TypeError("Expected argument 'server_name' to be a str")
        pulumi.set(__self__, "server_name", server_name)
        if user_name and not isinstance(user_name, str):
            raise TypeError("Expected argument 'user_name' to be a str")
        pulumi.set(__self__, "user_name", user_name)

    @_builtins.property
    @pulumi.getter(name="enablePki")
    def enable_pki(self) -> _builtins.bool:
        """
        Enable PKI
        """
        return pulumi.get(self, "enable_pki")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The id of the object
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        """
        Repository name should be less than 80 characters and can contain alphanumeric, underscore, hyphen and dot characters.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def password(self) -> _builtins.str:
        """
        Password can contain alphanumeric and/or special characters.
        """
        return pulumi.get(self, "password")

    @_builtins.property
    @pulumi.getter
    def path(self) -> _builtins.str:
        """
        Path should always start with "/" and can contain alphanumeric, underscore, hyphen and dot characters.
        """
        return pulumi.get(self, "path")

    @_builtins.property
    @pulumi.getter
    def protocol(self) -> _builtins.str:
        """
        Protocol
        """
        return pulumi.get(self, "protocol")

    @_builtins.property
    @pulumi.getter(name="serverName")
    def server_name(self) -> _builtins.str:
        """
        Name of the server
        """
        return pulumi.get(self, "server_name")

    @_builtins.property
    @pulumi.getter(name="userName")
    def user_name(self) -> _builtins.str:
        """
        User name
        """
        return pulumi.get(self, "user_name")


class AwaitableGetRepositoryResult(GetRepositoryResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetRepositoryResult(
            enable_pki=self.enable_pki,
            id=self.id,
            name=self.name,
            password=self.password,
            path=self.path,
            protocol=self.protocol,
            server_name=self.server_name,
            user_name=self.user_name)


def get_repository(id: Optional[_builtins.str] = None,
                   name: Optional[_builtins.str] = None,
                   opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetRepositoryResult:
    """
    This data source can read the Repository.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ise as ise

    example = ise.system.get_repository(id="repo1")
    ```


    :param _builtins.str id: The id of the object
    :param _builtins.str name: Repository name should be less than 80 characters and can contain alphanumeric, underscore, hyphen and dot characters.
    """
    __args__ = dict()
    __args__['id'] = id
    __args__['name'] = name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('ise:system/getRepository:getRepository', __args__, opts=opts, typ=GetRepositoryResult).value

    return AwaitableGetRepositoryResult(
        enable_pki=pulumi.get(__ret__, 'enable_pki'),
        id=pulumi.get(__ret__, 'id'),
        name=pulumi.get(__ret__, 'name'),
        password=pulumi.get(__ret__, 'password'),
        path=pulumi.get(__ret__, 'path'),
        protocol=pulumi.get(__ret__, 'protocol'),
        server_name=pulumi.get(__ret__, 'server_name'),
        user_name=pulumi.get(__ret__, 'user_name'))
def get_repository_output(id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                          name: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                          opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetRepositoryResult]:
    """
    This data source can read the Repository.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ise as ise

    example = ise.system.get_repository(id="repo1")
    ```


    :param _builtins.str id: The id of the object
    :param _builtins.str name: Repository name should be less than 80 characters and can contain alphanumeric, underscore, hyphen and dot characters.
    """
    __args__ = dict()
    __args__['id'] = id
    __args__['name'] = name
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('ise:system/getRepository:getRepository', __args__, opts=opts, typ=GetRepositoryResult)
    return __ret__.apply(lambda __response__: GetRepositoryResult(
        enable_pki=pulumi.get(__response__, 'enable_pki'),
        id=pulumi.get(__response__, 'id'),
        name=pulumi.get(__response__, 'name'),
        password=pulumi.get(__response__, 'password'),
        path=pulumi.get(__response__, 'path'),
        protocol=pulumi.get(__response__, 'protocol'),
        server_name=pulumi.get(__response__, 'server_name'),
        user_name=pulumi.get(__response__, 'user_name')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
from .. import _utilities
import typing
# Export this package's modules as members:
from .get_license_tier_state import *
from .get_repository import *
from .license_tier_state import *
from .repository import *
from ._inputs import *
from . import outputs
